function [poly1,poly2] = approxSector(center, radius, forbidWidth, centerAngle, numLinear)
% Cuts out a sector of a circle centered at 'center' and with radius 'radius'.
% The piece removed has forbidden width of 'forbidWidth' degrees and the middle
% ray is given by the angle centerAngle. The polytopes returned forms an
% inner approximation of the the remaining part of the circle


poly1=[];
poly2=[];

centerAngle = centerAngle*pi/180;
forbidWidth = forbidWidth*pi/180;

if forbidWidth < pi
    % Forbidden sector renders the feasile space non-convex. Splitting into
    % two sectors.
    centerAngle1 = centerAngle - pi/2 - forbidWidth/4+pi;
    if centerAngle1<0
        centerAngle1=centerAngle1+2*pi;
    end

    centerAngle2 = centerAngle + pi/2 + forbidWidth/4-pi;
    if centerAngle2 > 2*pi
        centerAngle2=centerAngle2-2*pi;
    end
    
    forbidWidthNew = pi + forbidWidth/2;
    %forbidWidth2 =

    numPoints = numLinear - 1;
    cpoint1 = [radius*sin(centerAngle1+forbidWidthNew/2) radius*cos(centerAngle1+forbidWidthNew/2)];
    cpoint2 = [radius*sin(centerAngle1-forbidWidthNew/2) radius*cos(centerAngle1-forbidWidthNew/2)];
    %rotation = 1;
    %axis([-2 2 -2 2]);
    %plot(cpoint1(1),cpoint1(2),'+')
    %hold on
    %plot(cpoint2(1),cpoint2(2),'+')
    Points=[0 0;cpoint1;cpoint2];
    pointSpacing = (2*pi-forbidWidthNew)/numPoints;
    angle = centerAngle1-forbidWidthNew/2;
    for i = 1:numPoints
        angle =  angle - pointSpacing;
        cpoint = [radius*sin(angle) radius*cos(angle)];
        Points = [Points; cpoint];
        %plot(cpoint(1),cpoint(2),'+')
        %hold on
    end
    %Points
    feasSpace = convh(Points);
    %feasSpace =ltran(feasSpace,eye(2),center);

    poly1=faces(feasSpace);


    numPoints = numLinear - 1;
    cpoint1 = [radius*sin(centerAngle2+forbidWidthNew/2) radius*cos(centerAngle2+forbidWidthNew/2)];
    cpoint2 = [radius*sin(centerAngle2-forbidWidthNew/2) radius*cos(centerAngle2-forbidWidthNew/2)];
    %rotation = 1;
    %axis([-2 2 -2 2]);
    %plot(cpoint1(1),cpoint1(2),'+')
    %hold on
    %plot(cpoint2(1),cpoint2(2),'+')
    Points=[0 0;cpoint1;cpoint2];
    pointSpacing = (2*pi-forbidWidthNew)/numPoints;
    angle = centerAngle2-forbidWidthNew/2;
    for i = 1:numPoints
        angle =  angle - pointSpacing;
        cpoint = [radius*sin(angle) radius*cos(angle)];
        Points = [Points; cpoint];
        %plot(cpoint(1),cpoint(2),'+')
        %hold on
    end
    %Points
    feasSpace = convh(Points);
    %feasSpace =ltran(feasSpace,eye(2),center);

    poly2=faces(feasSpace);

   % mp_PlotPoly(poly1);
    %mp_PlotPoly(poly2);


else
    if nargout < 2
        poly2=[];
    end
    numPoints = numLinear - 1;
    cpoint1 = [radius*sin(centerAngle+forbidWidth/2) radius*cos(centerAngle+forbidWidth/2)];
    cpoint2 = [radius*sin(centerAngle-forbidWidth/2) radius*cos(centerAngle-forbidWidth/2)];
    %rotation = 1;
    %axis([-2 2 -2 2]);
    %plot(cpoint1(1),cpoint1(2),'+')
    %hold on
    %plot(cpoint2(1),cpoint2(2),'+')
    Points=[0 0; cpoint1;cpoint2];
    pointSpacing = (2*pi-forbidWidth)/numPoints;
    angle = centerAngle-forbidWidth/2;
    for i = 1:numPoints
        angle =  angle - pointSpacing;
        cpoint = [radius*sin(angle) radius*cos(angle)];
        Points = [Points; cpoint];
        %plot(cpoint(1),cpoint(2),'+')
        %hold on
    end
    %Points
    feasSpace = convh(Points);
    %feasSpace =ltran(feasSpace,eye(2),center);

    poly1=faces(feasSpace);
  %  disp('HERE')
  %  mp_PlotPoly(poly1)
end

%feasSpace = convh(Points)
%feasSpace = convh(Points);

%mp_PlotPoly(faces(feasSpace));


%
% plot(cpoint1(1),cpoint1(2),'+')
% hold on
% plot(cpoint2(1),cpoint2(2),'+')