%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%MPC algorithm for Control Allocation.
%Assuming the optimal values T* og alpha* given (the desired alpha and T,
%computed by e.g using explicit solution for varying alpha, see report).
%The MPC algorithm computes T and alpha to be applied to the plant, taking
%rate constraints into consideration.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;


na=8;      %number of actuators (azimuth)
N=4;       %prediksjonshorisont

%lager H
H=[];
q=2;    %weight in each step - u
r=1;    %weight in each step - alpha
I=eye(N*na);
Q=q*I;
R=q*I;
H=2*blkdiag(Q,R);   %bde for delta_alfra og delta_u


%Optimaliseringsvektoren: [u1 u2 ... uN alpha1 alpha2 ... alphaN]^T

%unequality contraints:
%d_alpha_max:

I=eye(na);
A=zeros(na,na*N);

A1=A;
A2=A;
shiftA1=A;
shiftA2=A;
%A1: lower bound on delta_alpha
%A2: upper bound on delta_alpha
%A3: lower bound on delta_u
%A4: upperbound on delta_u

A1(1:na,1:na)=-I;
A2(1:na,1:na)=I;

shiftA1(1:na,1:2*na)=[I -I];
shiftA2(1:na,1:2*na)=[-I I];
A1=[A1; shiftA1];
A2=[A2; shiftA2];
for i=1:N-2
shiftA1=circshift(shiftA1,[0 na]); %shift na steps to the right
A1=[A1; shiftA1];
shiftA2=circshift(shiftA2,[0 na]);
A2=[A2; shiftA2];
end
Auneq_alpha=[A1; A2];
Auneq_u=[A1; A2];

Auneq=blkdiag(Auneq_u,Auneq_alpha);

%lower and upper bounds:
rate_alfa_min = ones(na,1)*-0.3;   %finne ut endringsratene for disse, n: like for alle.
rate_alfa_max= ones(na,1)*0.3;
rate_u_min = ones(na,1)*-1.2;
rate_u_max = ones(na,1)*1.2;

%rate_alfa_min=-[0.1 0.01 0.5 1 0.2 0.3 4 0.2]';

buneq1=[];
buneq2=[];
buneq3=[];
buneq4=[];

for i=1:N
   buneq1=[buneq1;-rate_alfa_min];
   buneq2=[buneq2;rate_alfa_max];
   buneq3=[buneq3;-rate_u_min];
   buneq4=[buneq4;rate_u_max];
end

buneq=[buneq3;buneq4;buneq1;buneq2];

f=zeros(1,N*2*na); %f^T*x til optimaliseringen

nn = 100; %Antall simuleringssteg

%Alpha* and T*: Assuming the following optimal values:
Tf=[-10 15 5 -8 12 6 2 3]';
Af=[1 -2 3 1 -2.5 3.5 4 5]';
Tf2=[-8 12 7 -10 10 6 0 5]';
Af2=[0 -5 2 5 -8 5 -4 6]';

%generating a reference-vector (T*, alpha*)
ref1=[Tf;Af];
ref2=[Tf2;Af2];
r1=mmult(ref1, [zeros(1, 20) ones(1, nn/2-20)]);
r2=mmult(ref2, [zeros(1, 20) ones(1, nn/2-20)]);
r=[r1 r2];

alpha0=zeros(na,1);
u0=zeros(na,1);
alpha_k=zeros(na,1);
u_k=zeros(na,1);

A=[];
U=[];

Buneq=buneq;

tic
for i=1:nn
   
    %ref=kron(ones(N,1),r(1:6,i));    %Assuming future references iqual to the present
    ref=[kron(ones(N,1),r(1:na,i)); kron(ones(N,1),r(na+1:na+na,i))];
    
    %M oppdatere Bulik for hvert steg:
    Buneq(1:na)=buneq(1:na)-u0;
    Buneq(na*N+1:na*N+na)=buneq(na*N+1:na*N+na)+u0;
    Buneq(2*na*N+1:2*na*N+na)=buneq(2*na*N+1:2*na*N+na)-alpha0;
    Buneq(3*na*N+1:3*na*N+na)=buneq(3*na*N+1:3*na*N+na)+alpha0;
    
    f=-2*ref'*blkdiag(Q,R);
    
    %Optimazation
     sol = quadprog(H,f,Auneq,Buneq,[],[],[],[],[],optimset('Display','off','LargeScale','off'));
    
    %Updating
    alpha0=alpha_k;
    u0=u_k;
    u_k= sol(1:na);
    alpha_k= sol(na*N+1 : na*N+na);
    A(1:na,i)=alpha_k;
    U(1:na,i)=u_k;
    
end

disp(['Simulation took ',num2str(toc),' seconds to complete.'])

%%%%%%%%%%%
%Plotting
figure
t = (1:1:nn);
plot(t,r(1:na,:),'.',t,U(1:na,:))  %reference T dotted, computed T line
title('T^* : dotted, T computed: line')


figure
plot(t,r(na+1:2*na,:),'.',t,A(1:na,:))  %reference alpha dotted, computed alpha line
title('\alpha^* : dotted, \alpha computed: line')
xlabel('Time [ms]')
ylabel('Angle [rad]')
%%%%%%%%%%%%





