%mpc-algoritme, assuming reference value tau given. Computes optimal T* and
%alpha* using the function opt_qp_f. Uses mpc to compute T and alpha, with
%given constaints.

clear all;
close all;
     
na=8;      %number of actuators 
N=3;       %prediksjonshorisont

%making H
H=[];
q=2;    %weight in each step - u
r=500;    %weight in each step - alpha
I=eye(N*na);
Q=q*I;
R=q*I;
H=2*blkdiag(Q,R);   %bde for delta_alfra og delta_u

%Optimaliseringsvektoren: [u1 u2 ... uN alpha1 alpha2 ... alphaN]^T

%unequality contraints:
%d_alpha_max:

I=eye(na);
A=zeros(na,na*N);

A1=A;
A2=A;
shiftA1=A;
shiftA2=A;
%A1: lower bound on delta_alpha
%A2: upper bound on delta_alpha
%A3: lower bound on delta_u
%A4: upperbound on delta_u

A1(1:na,1:na)=-I;
A2(1:na,1:na)=I;

shiftA1(1:na,1:2*na)=[I -I];
shiftA2(1:na,1:2*na)=[-I I];
A1=[A1; shiftA1];
A2=[A2; shiftA2];
for i=1:N-2
shiftA1=circshift(shiftA1,[0 na]); %shift na steps to the right
A1=[A1; shiftA1];
shiftA2=circshift(shiftA2,[0 na]);
A2=[A2; shiftA2];
end
Auneq_alpha=[A1; A2];
Auneq_u=[A1; A2];

Auneq=blkdiag(Auneq_u,Auneq_alpha);

%lower and upper bounds:
rate_alfa_min = ones(na,1)*-0.3;   %finne ut endringsratene for disse, n: like for alle.
rate_alfa_max= ones(na,1)*0.3;
rate_u_min = ones(na,1)*-0.9;
rate_u_max = ones(na,1)*0.9;

%rate_alfa_min=-[0.1 0.01 0.5 1 0.2 0.3 4 0.2]';

buneq1=[];
buneq2=[];
buneq3=[];
buneq4=[];

for i=1:N
   buneq1=[buneq1;-rate_alfa_min];
   buneq2=[buneq2;rate_alfa_max];
   buneq3=[buneq3;-rate_u_min];
   buneq4=[buneq4;rate_u_max];
end

buneq=[buneq3;buneq4;buneq1;buneq2];

f=zeros(1,N*2*na); %f^T*x til optimaliseringen

%initialization
alpha0=zeros(na,1);
u0=zeros(na,1);
alpha_k=zeros(na,1);
u_k=zeros(na,1);
A=[];
U=[];
Af_=[];
Tf_=[];

Buneq=buneq;

nn = 100; %Antall simuleringssteg
%Constructing a reference tau (from control system)
r1=mmult([10;10;0], [zeros(1, 20) ones(1, nn/2-20)]);
r2=mmult([-10;-10;0], [zeros(1, 20) ones(1, nn/2-20)]);
% r1=mmult([10;10;0], [zeros(1, 20) ones(1, nn/2-20)]);
% r2=mmult([-10;-10;0], [ones(1, nn/2-20) zeros(1, 20) ]);
r=[r1 r2];

tic 
for i=1:nn   
    tau=r(1:3,i);
    [Tf,Af] = opt_qp_f(tau);
    
    %ref=kron(ones(N,1),r(1:6,i));    
    ref=[kron(ones(N,1),Tf); kron(ones(N,1),Af)];   %Assuming future references iqual to the present
    
    %M oppdatere Bulik for hvert steg:
    Buneq(1:na)=buneq(1:na)-u0;
    Buneq(na*N+1:na*N+na)=buneq(na*N+1:na*N+na)+u0;
    Buneq(2*na*N+1:2*na*N+na)=buneq(2*na*N+1:2*na*N+na)-alpha0;
    Buneq(3*na*N+1:3*na*N+na)=buneq(3*na*N+1:3*na*N+na)+alpha0;
    
    f=-2*ref'*blkdiag(Q,R);
    
    %Optimazation
    sol = quadprog(H,f,Auneq,Buneq,[],[],[],[],[],optimset('Display','off','LargeScale','off'));
    %Updating
    alpha0=alpha_k;
    u0=u_k;
    u_k= sol(1:na);
    alpha_k= sol(na*N+1 : na*N+na);
    A(1:na,i)=alpha_k;
    U(1:na,i)=u_k;
    Af_=[Af_ Af];
    Tf_=[Tf_ Tf];   
end

disp(['Simulation took ',num2str(toc),' seconds to complete.'])

%plotting
t = (1:1:nn);
plot(t,Tf_(1:na,:),'.',t,U(1:na,:))
title('T^* : dotted, T computed: line')
xlabel('Time [ms]')
ylabel('Thrust magnitude [N]')

figure
plot(t,Af_(1:na,:),'.',t,A(1:na,:))
title('\alpha^* : dotted, \alpha computed: line')
xlabel('Time [ms]')
ylabel('Angle [rad]')


%Sjekk av tau og tau_strek




