%Rig parameter file
load cyberrig1modelABC.mat;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      Mass, damping and gravitational matrices      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M = [70.75 0       0   0 0 0;
     0      70.75  0   0 0 0;
     0      0       1  0 0 0;
     0      0       0   1.01 0 0;
     0      0       0   0 0.97 0;
     0      0       0   0 0 92.7];
D = [37.84 0       0   0 0 0;
     0      37.84  0   0 0 0;
     0      0       1   0 0 0;
     0      0       0   0.64 0 0;
     0      0       0   0 0.74 0;
     0      0       0   0 0 52.03];
G = [0      0       0   0 0 0;
     0      0       0   0 0 0;
     0      0       1   0 0 0;
     0      0   0 14.21 0   0;
     0      0   0   0 14.21 0;
     0      0       0   0 0 0];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   Wave model                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Omega = diag([0.8 0.8 0.8 0.8 0.8 0.8]);
Lambda = diag([0.1 0.1 0.1 0.1 0.1 0.1]);
A_w = [zeros(6) eye(6);
       -Omega^2 -2*Lambda*Omega];
C_w = [zeros(6) eye(6)];
E_w = [diag([3 3 3 3 3 0.8])*0;diag([1 1 1 1 1 1])];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                  System model                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T_b=eye(6)*10;

A = [A_w         zeros(12,6) zeros(12,6) zeros(12,6);
     zeros(6,12) zeros(6)    zeros(6)    eye(6);
     zeros(6,12) zeros(6)    -inv(T_b)    zeros(6);
     zeros(6,12) -inv(M)*G    inv(M)    -inv(M)*D];

H_30to24 = [eye(12) zeros(12,6) zeros(12,6) zeros(12,6); 
            zeros(6,12) eye(6)  zeros(6) zeros(6);
            zeros(6,12) zeros(6) eye(6) zeros(6)];

B = [zeros(12,6);zeros(6);zeros(6);inv(M)];

E_b = eye(6);
H = [C_w eye(6) zeros(6) zeros(6)];

E = [E_w      zeros(12,6) zeros(12,6);
     zeros(6) zeros(6)    zeros(6);
     zeros(6) E_b         zeros(6);
     zeros(6) zeros(6)    inv(M)];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Kalman Filter Patameters model              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Parameter covariance
Q = diag([0.1 0.1 0.1 0.1 0.1 0.1 700 700 700 700 700 700 1 1 1 1 1 1])*10e-5; 
%Measurement covariance 
R = diag([1 1 1 1 1 1])*10e-7;

[K,P_inf]=lqe(A,E,H,Q,R); %steady-state Kalman gain


   