/*
 * readpos_c.c: Level 2 S-function for communicating with QTM TCP/IP server 
 * 
 * Author:  Torgeir Wahl, NTNU
 * Updated: 11.08.2004
 * Version: 1.0
 * 
 *          14.05.2006: Jonas Tyss, Asbjrn Hamre Aga
 *                                      - All printf replaced by OpalPrint.
 *                                      - Modified to output radians instead of deg.
 *                                      - Modified incorrect error message
 */


#define S_FUNCTION_NAME  readpos_c
#define S_FUNCTION_LEVEL 2

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/select.h>
#include <sys/time.h>
#include <netinet/in.h>
#include <netdb.h>
#include <stdio.h> 
#include <string.h> 
#include <stdlib.h>
#include <unistd.h>
#include <arpa/inet.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include "simstruc.h"
#include "tmwtypes.h"
#include "OpalPrint.h"


#define CONTSTATES 1 /* Number of continuous states */
#define NCHANNELS 2
#define MAX_NOF_DATABYTES 0x500
#define NOF_CHANNELS 10
#define SIZE_PPU_HEADER					4
#define SIZE_PPU_FOOTER					2
#define SIZE_UNIDENTIFIED_DATA_HEADER	5
#define SIZE_UNIDENTIFIED_DATA_BODY		16
#define SIZE_IDENTIFIED_DATA_HEADER		5
#define SIZE_IDENTIFIED_DATA_BODY		17
#define SIZE_6DOF_DATA_HEADER			5
#define SIZE_6DOF_DATA_BODY				32
#define SIZE_ROTATION_DATA_HEADER		5
#define SIZE_ROTATION_DATA_BODY			56

#define FRAME_START						0x01
#define FRAME_TERMINATOR				0x04

#define FRAME_BUFFER_MAX_SIZE			10000
#define MAX_NUMBER_OF_BODIES			20

/* Frame formats */
#define QTM_FrameTypeError              0x01 /* Error frame,                        type 0 */
#define QTM_FrameTypeCalibration        0x02 /* Calibration frame,                  type 1 */
#define QTM_FrameTypeVerification       0x04 /* Verification frame,                 type 2 */
#define QTM_FrameTypeUnidentified3D     0x08 /* Frame with unidentified 3D markers, type 3 */
#define QTM_FrameTypeIdentified3D       0x10 /* Frame with identified 3D markers,   type 4 */
#define QTM_FrameType6DOF               0x20 /* Frame with 6DOF data,               type 5 */
#define QTM_FrameTypeRotationMatrix     0x40 /* Frame with rotation matrix,         type 6,*/

typedef unsigned char BYTE;
typedef unsigned long DWORD;
typedef BYTE *LPBYTE;
typedef int BOOL;
typedef unsigned short WORD;


BOOL	ibContinuousTransmission = FALSE;
BOOL	ibIncompleteFrame	= FALSE;
BYTE		inFrameTypes		= QTM_FrameType6DOF;
unsigned int		NoOfFrames  = 1;
int DebugOpalPrint = 0;//FALSE; /* = 1 -> prints out _all_ status and error messages */
int errorcode, sock, SelectStatus;
struct timeval tv;
fd_set SockFD;
struct sockaddr_in unit;
struct hostent *hp;
int port = 1221;
int SendStatus;
//char serveraddr[] = "dhcp-140230i.marin.ntnu.no";
//char serveraddr[] = "129.241.140.230";
char serveraddr[] = "192.168.0.10";
//char serveraddr[] = "127.0.0.1";



/*****************************************************************************
*****************************************************************************/
void nonBlockMode()
{
	int flags;

	flags = fcntl(sock, F_GETFL);
	flags = flags | O_NONBLOCK;
	fcntl(sock, F_SETFL, flags);
}


/*****************************************************************************
* Function...: I_Send
* Description: Sends data to QTM
* Arguments..: 
* Remark.....: 
*****************************************************************************/
BOOL	I_Send(const char *pBuffer, DWORD nBytesToSend, DWORD *nBytesSent)
{
	FD_ZERO(&SockFD);
	FD_SET(sock, &SockFD);
	/* Write data to server */
	if((SelectStatus = select(1+sock, 0, &SockFD, 0, &tv)) > 0)
	{
		*nBytesSent = send (sock, pBuffer, nBytesToSend, 0);
		if (*nBytesSent < 0)
		{
			if (!DebugOpalPrint)
			{
				OpalPrint("SFUN_ETHERNET: ERROR: Couldn't send data to server\n");
				errorcode = -1;
				return(FALSE);
			}
		}
		else
		{
			if (DebugOpalPrint)
			{
			OpalPrint("SFUN_ETHERNET: Request = \"%s\" sent to server  %d\n", pBuffer, *nBytesSent);
			return(TRUE);
			}
		}
	}
	else
	{
		OpalPrint("SFUN_ETHERNET: ERROR: Select write error: %d\n", SelectStatus);
		errorcode = -2;
		return(FALSE);
	}
}
/*****************************************************************************
* Function...: I_SendModeCommad
* Description: Sends the M command
* Returns....: True if ok, else false
*****************************************************************************/
BOOL I_SendModeCommand( void )
{

	char strCommand[7];
	DWORD nBytesWritten;
	
	sprintf(strCommand, "#M%02x0%01x\r", inFrameTypes, ibContinuousTransmission);
	
	if (!I_Send((char*)strCommand, 7, &nBytesWritten) ||
		(nBytesWritten != 7))
	{
		// Errors set by I_Send
		return false;
		
	}
	return true;
}

/*****************************************************************************
* Function......: GetData
* Description: 	Ask for data by sending request to TCP/IP server
* Returns........: TRUE if data i pBuffer is a valid frame
*****************************************************************************/
BOOL GetData(BYTE *pBuffer, DWORD nBytesToRead, DWORD *nBytesRead)
{
	char	Request[10], *command = "#T0001\r";
	DWORD	nBytesWritten;
	
	strcpy(Request, command);
	if(I_Send(Request, sizeof(Request), &nBytesWritten))
	{
		delay(10);
		FD_ZERO(&SockFD);
		FD_SET(sock, &SockFD);
		/* Receive data from server */
		switch (SelectStatus = select(1+sock, &SockFD, 0, 0, &tv))
		{
		case -1:
            OpalPrint("SFUN_ETHERNET: ERROR: Select error\n");
            break;
		case 0:
            OpalPrint("SFUN_ETHERNET: WARNING: Select timed out on receive\n");
            break;
		default:
			if (FD_ISSET(sock, &SockFD))
			{
				*nBytesRead = recv (sock, pBuffer, nBytesToRead, 0);
				if (DebugOpalPrint)
				{
					OpalPrint("SFUN_ETHERNET: Received %d bytes from server\n", *nBytesRead);
				}
			return(TRUE);
			}
		}
	}
	return(FALSE);
}

/*****************************************************************************
* Function...: I_IsAFrame
* Returns....: TRUE if data i pBuffer is a valid frame
*****************************************************************************/
BOOL I_IsAFrame( const LPBYTE pBuffer, DWORD nByteCount, DWORD *nFrameSize )
{
	int i;
	
	// Start of frame?
	if (pBuffer[0] == FRAME_START )
	{
		// Yes, it is big enough?
		if (nByteCount>= SIZE_PPU_HEADER + SIZE_PPU_FOOTER)
		{
			// Yes, did we receive the entire frame?
			*nFrameSize = *(WORD*)&pBuffer[ 1 ];
			
			if (*nFrameSize > nByteCount)
			{
				errorcode = -3;
				return false;
			}

			return (pBuffer[*nFrameSize - 1] == FRAME_TERMINATOR);
		}
	}
	for(i = 0; i < nByteCount; i++)
	{
        if (DebugOpalPrint)
        {
            OpalPrint("%-4x  ", pBuffer[i]);
        }
	}
    if (DebugOpalPrint)
    {
        OpalPrint("\n");
    }
	errorcode = -4;

	return false;
}


/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
static void mdlInitializeSizes(SimStruct *S)
{
    ssSetNumSFcnParams(S, 2);  /* Number of expected parameters */
    if (ssGetNumSFcnParams(S) != ssGetSFcnParamsCount(S)) {
        return; /* Parameter mismatch will be reported by Simulink */
    }

    ssSetNumContStates(S, CONTSTATES);
    ssSetNumDiscStates(S, 0);

    if (!ssSetNumInputPorts(S, 1)) return;
    ssSetInputPortWidth(S, 0, CONTSTATES);
    ssSetInputPortDirectFeedThrough(S, 0, 0);

    if (!ssSetNumOutputPorts(S, 1)) return;
    ssSetOutputPortWidth(S, 0, NOF_CHANNELS);

    ssSetNumSampleTimes(S, 1);
    ssSetNumRWork(S, 0);
    ssSetNumIWork(S, 0);
    ssSetNumPWork(S, 0);
    ssSetNumModes(S, 0);
    ssSetNumNonsampledZCs(S, 0);

    /* Take care when specifying exception free code - see sfuntmpl.doc */
    ssSetOptions(S, SS_OPTION_EXCEPTION_FREE_CODE);
}

/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
static void mdlInitializeSampleTimes(SimStruct *S)
{
    ssSetSampleTime(S, 0, CONTINUOUS_SAMPLE_TIME);
    ssSetOffsetTime(S, 0, 0.0);
}

/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
#define MDL_INITIALIZE_CONDITIONS
static void mdlInitializeConditions (SimStruct *S)
{
    real_T *x0 = ssGetContStates(S);
    int i, retv;
	int Success = 0;
    InputRealPtrsType uPtrs = ssGetInputPortRealSignalPtrs(S,0);

/************************************************
    for (i=0;i<CONTSTATES;i++)
	{
		x0[i] = 0.0;
    }
************************************************/

	//	Initialize client by creating socket and connect to TCP/IP server
	sock = socket(AF_INET, SOCK_STREAM,0);
	if (sock < 0)
	{
		if (!DebugOpalPrint)
		{
			errorcode = -5;
			retv = printf("SFUN_ETHERNET: ERROR: Couldn't open stream socket\n");
		}
	}
	else
	{
		if (DebugOpalPrint)
		{
			OpalPrint("SFUN_ETHERNET: Created socket: %d\n", sock);
		}
	}
	
	tv.tv_sec = 0;
	tv.tv_usec = 6000; // Wait 6 ms

	unit.sin_family = AF_INET;
	unit.sin_port = htons(port);
	
	
	hp = gethostbyname(serveraddr);
//	hp = gethostbyaddr(serveraddr, sizeof(serveraddr), unit.sin_family);
	herror(NULL);
	if (hp != NULL)
	{
		Success = 1;
		memcpy(&unit.sin_addr, hp->h_addr, hp->h_length);
		if (DebugOpalPrint)
		{
			OpalPrint("\nSFUN_ETHERNET: Gethostbyname returned: %d\n", *hp);
		}
	}
	else if ((unit.sin_addr.s_addr = inet_addr(serveraddr)) == INADDR_NONE)
	{
		Success = 0; 
		if (!DebugOpalPrint)
		{
			errorcode = -6;
			OpalPrint("SFUN_ETHERNET: ERROR: Couldn't determine ip address\n");
		}
	}
	
	if ((DebugOpalPrint)&&(Success))
	{
		OpalPrint("SFUN_ETHERNET: Got hostaddress successfully\n");
		OpalPrint("SFUN_ETHERNET: Converted ip address: %d\n", unit.sin_addr.s_addr);
	}
	nonBlockMode();
	
	FD_ZERO(&SockFD);
	FD_SET(sock, &SockFD);
	/* Write data to server */
//	if((SelectStatus = select(1+sock, 0, &SockFD, 0, &tv)) > 0)
//	{
		retv = connect(sock, (struct sockaddr *)&unit, sizeof(unit));			
		if (retv < 0)
		{
			if (!DebugOpalPrint)
			{
				errorcode = -7;
				//OpalPrint("SFUN_ETHERNET: ERROR: Couldn't connect to server %d\n", errno); 
                //This was uncommented in the original driver.
			}
		}
		else
		{
			if (DebugOpalPrint)
			{
				OpalPrint("SFUN_ETHERNET: Connected to TCP/IP server!\n");
			}
		}

		/* Set Frame type to receive  */
		I_SendModeCommand();
		delay(20);
//	}
}
/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
#define MDL_UPDATE
static void mdlUpdate(SimStruct *S, int_T tid)
{
}

/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
static void mdlOutputs(SimStruct *S, int_T tid)
{
	unsigned char Answer[MAX_NOF_DATABYTES];
	DWORD	BytesReceived = 0, nFrameSize = 0;
	int 	i, SizeOfDataArray, promptsize = 0; // 19;
	int NumOfBytesInDataFormat = 4;
	unsigned char *cp;
	BOOL	retv;
	DWORD	noffset;
	
	real_T   *y = ssGetOutputPortRealSignal(S, 0);
//	float		y[100];
	errorcode = 10;
	
	for(i = 0; i < NoOfFrames; i++)
	{
		retv = GetData(Answer, sizeof(Answer), &BytesReceived);

		if(i == 0) {
			cp = &Answer[promptsize];
			BytesReceived = BytesReceived - promptsize;
			noffset = SIZE_PPU_HEADER;
		}
		else {
			noffset = SIZE_PPU_HEADER;
			cp = Answer;
		}
		if(retv)
		{
			if(I_IsAFrame(Answer, BytesReceived , &nFrameSize))
			{
				y[0] = (float)(*(DWORD *)(cp + noffset));		// FrameNumber
				noffset += 4;
				y[1] = (float)*(cp + noffset);				// NoOfBodies
				noffset++;
				y[2] = *(float *)(cp + noffset);			// X
				noffset += 4;
				y[3] = *(float *)(cp + noffset);			// Y
				noffset += 4;
				y[4] = *(float *)(cp + noffset);			// Z
				noffset += 4;
				y[5] = *(float *)(cp + noffset);	// roll in radians
				noffset += 4;
				y[6] = *(float *)(cp + noffset);	// pitch in radians
				noffset += 4;
				y[7] = *(float *)(cp + noffset);	// yaw in radians
				noffset += 4;
				y[8] = *(float *)(cp + noffset);			// residual
				y[9] = (float)errorcode;				// Internal error code
			}
			else
			{
				if (DebugOpalPrint)
				{
					OpalPrint("SFUN_ETHERNET: Framesize ERROR: %d\n", nFrameSize);
				}
			}
		}
		else
		{
			if (DebugOpalPrint)
			{
				OpalPrint("SFUN_ETHERNET: ERROR: No bytes received: %d bytes\n", BytesReceived);
			}
		}
		delay(25);
	}
	//OpalPrint("\n");
}

/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
#define MDL_DERIVATIVES
#if defined(MDL_DERIVATIVES)
static void mdlDerivatives(SimStruct *S)
{
}
#endif

/*****************************************************************************
* Function...: 
* Description: 
* Arguments..: 
* Remark.....: 
*****************************************************************************/
#define MDL_TERMINATE
#if defined (MDL_TERMINATE)
static void mdlTerminate(SimStruct *S)
{
	char 	strCommand[7];
	DWORD	nBytesWritten;
	
	strcpy(strCommand, "#E\r");
	I_Send(strCommand, 3, &nBytesWritten);
	close(sock);
	if (DebugOpalPrint)
	{
		OpalPrint("SFUN_ETHERNET: Socket %d closed\n", sock);
	}
}
#endif


#ifdef  MATLAB_MEX_FILE    /* Is this file being compiled as a MEX-file? */
#include "simulink.c"      /* MEX-file interface mechanism */
#else
#include "cg_sfun.h"       /* Code generation registration function */
#endif
