%mpc-algoritme, assuming reference value tau given. Cost function
%sigma(Bu-tau). Bruker approksimasjon for ratebetingelsene. 

clear all;
close all;
 
na=8;      %number of actuators 
N=6;       %prediksjonshorisont
dof=3;      %degrees of freedom

%Som i artikkel J.S.
l1y=0.365; l1x=-0.305;
l2y=0.305; l2x=-0.365;
l3y=-0.305; l3x=-0.365;
l4y=-0.365; l4x=-0.305;
l5y=-0.365; l5x=0.305;
l6y=-0.305; l6x=0.365;
l7y=0.305; l7x=0.365;
l8y=0.365; l8x=0.305;

Bb=[1 0 1 0 1 0 1 0 1 0 1 0 1 0 1 0;
    0 1 0 1 0 1 0 1 0 1 0 1 0 1 0 1;
    -l1y l1x -l2y l2x -l3y l3x -l4y l4x -l5y l5x -l6y l6x -l7y l7x -l8y l8x]; %Check

%Optimaliseringsvektoren: [u1,x u1,y u2,x u2,y ... uN,x uN,y]^T

%making cost function H
H=[];
for i=1:N-1
   H=blkdiag(H,2*Bb'*Bb) 
end
H=blkdiag(H,100*Bb'*Bb);

%%%%%%%%%%%%
%Sirkel som skal flyttes med u0, radius 0.5
[s1,s2] = approxSector([0 0]', 0.5, 0, 0, 5); %two half circles

sFinal=removeLine(s1,s2);   %making the two half circles into one whole
[s_A,s_b]=poly2Ab(sFinal);  %Make it to the form Ax<=b

%All actuators
SA=kron(eye(na),s_A);
Sb=kron(ones(na,1),s_b);

[a1,a2]=size(SA); 

if N==1
    temp=[1];
elseif N==2
    temp=[1 0; -1 1];
else
    temp=zeros(1,N);
    vec=zeros(1,N);
    vec([1 2])=[-1 1];
    temp(1)=1;
    temp=[temp;vec];
    for i=1:N-2
        vec=circshift(vec,[0 1]);
        temp=[temp; vec];
    end
end

Auneq1=kron(temp,SA);   %Auneq1: constraints, moving circle

buneq1=[];
for i=1:N
    buneq1=vertcat(buneq1,Sb);
end

%%%%%%%%%%
%adding constraints for forbidden sectors
[A,b] = forbiddenSectors();
Auneq2=kron(eye(N),A);          %Auneq2: contstraints, forbidden sectors
buneq2=kron(ones(N,1),b);
%%%%%%%%%%%%%
Auneq=[Auneq1;Auneq2];          %All contstraints
buneq=[buneq1;buneq2];
% Auneq=Auneq1;                 %Only moving circle constraints
% buneq=buneq1;
%%%%%%%%%%

%initialization
u0=zeros(2*na,1);
u_k=zeros(2*na,1);
U=[];       %the computed u, over the whole horizon
TAU_=[];    %the computed tau, over the whole horizon

nn = 100; %Number of simulation steps

%Constructing a reference tau (from control system)
r1=mmult([10;10;0], [zeros(1, 20) ones(1, nn/2-20)]);
r2=mmult([-10;-10;0], [zeros(1, 20) ones(1, nn/2-20)]);
r=[r1 r2];

U01=[];
U02=[];
T_=[];
A_=[];
alpha=[];
T=[];
Buneq=buneq;
tic 
for i=1:nn   
    tau=r(1:3,i);
    %Assuming future tau equal to the present
    
    f1=-2*Bb'*tau; 
    f=kron(ones(N,1),f1);
    
    
    %Updating constraints, moving with u0:
    Buneq(1:a1)=buneq(1:a1)+SA*u0;
    
    %Optimazation
    sol = quadprog(H,f,Auneq,Buneq,[],[],[],[],[],optimset('Display','off','LargeScale','off'));
    %sol = quadprog(H,f,[],[],[],[],[],[],[],optimset('Display','off','LargeScale','off')); %without constraints
    
    %Updating
    u0=u_k;
    u_k= sol(1:2*na);
    U(1:2*na,i)=u_k;
    tau_=Bb*u_k;
    TAU_(1:dof,i)=tau_;  
    
    alpha=[];
    T=[];
    for i=1:na
        ux=u_k(i);
        uy=u_k(i+1);
        alpha=[alpha; atan2(uy,ux)];             %ATAN2(Y,X) is the four quadrant arctangent of the real parts of the
        T=[T; sqrt(ux^2+uy^2)]  ;                           %     elements of X and Y.  -pi <= ATAN2(Y,X) <= pi.
    end
    T_=[T_ T];
    A_=[A_ alpha];
end

disp(['Simulation took ',num2str(toc),' seconds to complete.'])

figure
t = (1:1:nn);
plot(t,TAU_(1:dof,:),t,r(1:dof,:),'.')
title('Tau computed line, Tau reference dotted')
xlabel('time')
ylabel('Tau')

figure
title('alpha')
subplot(241), plot(t,A_(1,:))
subplot(242), plot(t,A_(2,:))
subplot(243), plot(t,A_(3,:))
subplot(244), plot(t,A_(4,:))
subplot(245), plot(t,A_(5,:))
subplot(246), plot(t,A_(6,:))
subplot(247), plot(t,A_(7,:))
subplot(248), plot(t,A_(8,:))

figure
title('T')
subplot(241), plot(t,T_(1,:))
subplot(242), plot(t,T_(2,:))
subplot(243), plot(t,T_(3,:))
subplot(244), plot(t,T_(4,:))
subplot(245), plot(t,T_(5,:))
subplot(246), plot(t,T_(6,:))
subplot(247), plot(t,T_(7,:))
subplot(248), plot(t,T_(8,:))

figure
i=1;
k=1;
while i<=16
    subplot(2,4,k), plot(U(i,:),U((i+1),:)), %plotting movement of actuators ux uy
    axis([-2.5 2.5 -2.5 2.5])
    title(['Actuator ',num2str(k)])
%     xlabel('u_x')
%     ylabel('u_y')    
    i=i+2;
    k=k+1;
end

figure
for i=1:16
    subplot(8,2,i), plot(t,U(i,:))  %plotter U som funskjon av tida
end

