%mpc-algoritme, assuming reference value tau given. Cost function
%sigma(Bu-tau). Bruker approksimasjon for ratebetingelsene. 

clear all;
close all;
 
na=1;      %number of actuators 
N=2;       %prediksjonshorisont
dof=3;      %degrees of freedom

%Som i artikkel J.S.
l1y=0.365; l1x=-0.305;


Bb=[1 0;
    0 1;
    -l1y l1x]; %Check

%Optimaliseringsvektoren: [u1,x u1,y u2,x u2,y ... uN,x uN,y]^T

%making cost function H
H=[];
for i=1:N
   H=blkdiag(H,2*Bb'*Bb) 
end

Auneq=[1 0 0 0;
    -1 0 0 0;
    0 1 0 0
    0 -1 0 0;
    0 0 1 0;
    0 0 -1 0;
    0 0 0 1;
    0 0 0 -1];

SA=[1 0;
    -1 0;
    0 1;
    0 -1];
buneq=[1 1 1 1 1 1 1 1]';
%initialization
u0=zeros(2*na,1);
u_k=zeros(2*na,1);
U=[];       %the computed u, over the whole horizon
TAU_=[];    %the computed tau, over the whole horizon

nn = 100; %Number of simulation steps

%Constructing a reference tau (from control system)
r1=mmult([10;10;0], [zeros(1, 20) ones(1, nn/2-20)]);
r2=mmult([-10;-10;0], [zeros(1, 20) ones(1, nn/2-20)]);
r=[r1 r2];

U01=[];
U02=[];
T_=[];
A_=[];
alpha=[];
T=[];
Buneq=buneq;
tic 
for i=1:nn   
    tau=r(1:3,i);
    %Assuming future tau equal to the present
    
    f1=-2*Bb'*tau; 
    f=kron(ones(N,1),f1);
    
    
    %Updating constraints, moving with u0:
    Buneq(1:4)=buneq(1:4)+SA*u0;
    
    %Optimazation
    sol = quadprog(H,f,Auneq,Buneq,[],[],[],[],[],optimset('Display','off','LargeScale','off'));
    %sol = quadprog(H,f,[],[],[],[],[],[],[],optimset('Display','off','LargeScale','off')); %without constraints
    
    %Updating
    u0=u_k;
    u_k= sol(1:2*na);
    U(1:2*na,i)=u_k;
    tau_=Bb*u_k;
    TAU_(1:dof,i)=tau_;  
    
    alpha=[];
    T=[];
    for i=1:na
        ux=u_k(i);
        uy=u_k(i+1);
        alpha=[alpha; atan2(uy,ux)];             %ATAN2(Y,X) is the four quadrant arctangent of the real parts of the
        T=[T; sqrt(ux^2+uy^2)]  ;                           %     elements of X and Y.  -pi <= ATAN2(Y,X) <= pi.
    end
    T_=[T_ T];
    A_=[A_ alpha];
end

disp(['Simulation took ',num2str(toc),' seconds to complete.'])

figure
t = (1:1:nn);
plot(t,TAU_(1:dof,:),t,r(1:dof,:),'.')
title('Tau computed line, Tau reference dotted')
xlabel('time')
ylabel('Tau')

figure
title('alpha')
subplot(241), plot(t,A_(1,:))


figure
title('T')
subplot(241), plot(t,T_(1,:))


figure
i=1;
k=1;
while i<=16
    subplot(2,4,k), plot(U(i,:),U((i+1),:)), %plotting movement of actuators ux uy
    axis([-2.5 2.5 -2.5 2.5])
    title(['Actuator ',num2str(k)])
%     xlabel('u_x')
%     ylabel('u_y')    
    i=i+2;
    k=k+1;
end

figure
for i=1:16
    subplot(8,2,i), plot(t,U(i,:))  %plotter U som funskjon av tida
end

