function S=defsimp(d);
%  DEFSIMP: define a regular centred simplex with edge size 1
%  Inputs:
%   d[1]  = dimension
%  Outputs:
%    S=[[0 eps;1 0.5;-1 0.5;-0.5 -1; 0.5 -1]] = simplex
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Set the global error parameters:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;end;
 
%  Define default output (finish 1D case):
 
S=[0 eps;1 0.5;-1 0.5;-0.5 -1; 0.5 -1];
if nargin<1,return;end;
 
%  Initialize generation of vertices:
 
v=zeros(d+1,d);v(1,1)=-0.5;v(2,1)=0.5;
 
%  Start cycle of generation of vertices :
 
a0=1;
for i=2:d,
  hlp1=mean(v(1:i,:));
  r=hlp1-v(1,:);ra=r*r';
  v(i+1,:)=[hlp1(1:i-1) sqrt(a0*a0-ra) zeros(1,d-i)];
  hlp=v(i,:)-v(i-1,:);
  a0=sqrt(hlp*hlp');
end;
 
%  Center to the origin:
 
v0=v-ones(d+1,1)*mean(v); 
 
%  Create the hyperplane list `H' :
 
H=[];
for i=1:d+1,
  if (i==1),j=2; else j=i-1;end;
  no=norm(v0(i,1:d));
  H=[H;-v0(i,1:d)/no, -v0(i,1:d)*v0(j,1:d)'/no]; 
end;
 
%  Define the simplex in GBT-format type 0 :
 
S  =[0 d+1  eps zeros(1,d-2);
         H              ;
        v0  ones(d+1,1) ];
 
return;
 
