echo %  M-file
%  This demo generates 3 random 3D ellipsoids
%  and approximates them by inner and outer bounding polytopes.
%  The volume of the intersection is estimated
%  and lower and upper bounds are given.
%  If this m-file does not run correctly please contact us
%  Email: gbt@sysbrain.com
 
%  Generate 3 random 3D ellipsoids:
 
d=3;  % dimension
n=3;  % no of ellipsoids
E=zeros(d+1,d+1,n);
for i=1:n,
   C=rand(10,d)-0.5;C=C'*C/2;
   E(:,:,i)=defell(C,0.1*rand(d,1));
end;
 
%  Generate hyperplanes of inner and outer approximations and
%  collect them in arrays `Hoall' and `Hiall'
 
nord=4; Hiall=[];Hoall=[];
for i=1:n,
   [Ho,Hi]=ellapprx(E(:,:,i),nord);
   Hoall=[Hoall; faces(Ho)];
   Hiall=[Hiall; faces(Hi)];
end;
 
%  Intersect all half-spcaces in `Hoall':
 
h1=size(Hoall,1);
B=defbox(-10*ones(1,d),10*ones(1,d)); % outer bound 
Pouter=B;
for i=1:h1, 
   Pouter=update(Hoall(i,:),Pouter);
end;
 
%  Intersect all halfs-spaces in 'Hiall':
 
h2=size(Hiall,1);
B=defbox(-10*ones(1,d),10*ones(1,d));
Pinner=B;
for i=1:h2, 
   Pinner=update(Hiall(i,:),Pinner);
end;
 
%  View the outer and inner approximations of intersection:
 
figure;ax=view2d(Pouter,[1 2 ]);view2d(Pinner,[1 2],'g',ax); %  no.figs=1
 
%   Volume computations fo both inner and outer polytope of intersection:
 
disp(' upper bound of volume:')
upvol=polvol(Pouter) 
disp('lower bound of volume:')
lovol=polvol(Pinner)
 
%  Estimate the intersection by the average of the internal and outer polytope volumes:
 
disp('estimate of intersection volume:')
(upvol+lovol)/2
 
echo off
