function [diam,ds,de]=diameter(P);
%   DIAMETER: compute the diameter of a polytope
%   Inputs:
%    P[[1 eps;1 1]] = polytope
%   Outputs:
%    diam[0] =  length of diameter
%     ds[1]  =  starting point of a diameter
%     de[1]  =  ending point of a diameter
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%   Define default values:
 
if nargin<1, P=[1 eps;1 1];end;
diam=0;ds=1;de=1;
 
%  Extract the vertices from the polytope
 
[V,nv]=vertices(P);
[nv,d]=size(V);
 
%   Deal  with the 1D case:
 
if (d==1),
    ds=min(V);de=max(V);diam=de-ds;
    return;
end;
 
%  Deal  with the general case:
 
  W=V*V';Z=diag(W)*ones(1,nv); X=Z+Z'-2*W;
  [cx,i]=max(X);[d0,j]=max(cx);
  ds=V(i(j(1)),:)'; de=V(j(1),:)';
  diam=sqrt((de-ds)'*(de-ds));
  return;
 
