function [e,S,v]=ELLADDI(e1,e2,S0);
%  ELLADDI:  compute inner bounding ellipsoid to the sum of two ellipsoids.
%  Inputs:
%    e1[[1 0;1 0]] = first ellipsoid
%    e2[[1 0;1 0]] = second ellipsoid
%     S0['vol']    = criterion of optimisation (options:'vol', given matrix)
%  Outputs:
%    e[1 0;4 0]  = outer bounding ellipsoid of the sum
%     S          = parameter matrix obtained
%     v          = criterion value received
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Define defaults:
 
if nargin<2, e2=[1 0;1 0]; elseif nargin<1, e1=[1 0;1 0];end;
e=[1 0;4 0];
if nargin<3, S0='vol';end;
 
%    Do diagnosis:
 
[ro1,co1]=size(e1);[ro2,co2]=size(e2);
if [ro1 co1]~=[ro2 co2], 
  disp('Dimensions of ellipsoids are different.');
  break; 
end;
n=ro1-1;
[roS0,coS0]=size(S0);
if ~isstr(S0) & [roS0 coS0]~=[n n], 
  disp('Dimensions of parameter matrix not correct.');
  break; 
end;
if      isstr(S0) ,
  if ~(S0=='vol')
    disp('Incorrect parameter string in ELLADDI.');
    break; 
  end;
end;
if ~isstr(S0),
  if ( ~(S0==S0') | min(eig(S0)) <= 0 )
    disp('Parameter matrix not positive definite.');
    break;
  end; 
end;
 
%  Start the algorithm of adding two ellipsoids:
 
Q1=e1(2:ro1,1:n);a1=e1(2:ro1,co1);
Q2=e2(2:ro1,1:n);a2=e2(2:ro1,co1);
if isstr(S0) ,
 
%   Calculate parameter for maximal volume:
 
	S = inv(sqrtm(Q2));
else
	S=S0;
end;
 
%   Build output ellipsoid representation:
 
a=a1+a2;
Q=S'^(-1)*((sqrtm(S*Q1*S')+sqrtm(S*Q2*S'))^2)*S^(-1);
e=[1 ones(1,n);Q a];
v=0;
if isstr(S0),
	v=det(Q);
end; 
return
 
