function [E,P]=ELLINTC(e1,e2);
%  ELLINTC: compute minimum convex combination of two ellipsoids
%  Inputs:
%    e1[[1 0;1 0]] = first ellipsoid
%    e2[[1 0;1 0]] = second ellipsoid
%  Outputs:
%     E[[1 0;1 1]] = ellipsoid around the intersection
%     P            = approximate polytope around the intersection
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%   Define defaults:
 
if nargin<4, nord=6;end;
if nargin<3, method=2;end;
if nargin<2, e2=[1 0;1 0];end;
if nargin<1, e1=[1 0;1 0];end;
E=[1 0;4 0];P=[0 eps;1 1;-1 1; -1 -1; 1 -1];
 
%  Input diagnostics:
 
if (e1(1,1)~=1), 
	disp('First object is not an ellipsoid');break; end;
if (e2(1,1)~=1), 
	disp('Second object is not an ellipsoid');break;end;
[ro1,co1]=size(e1);[ro2,co2]=size(e2);n=co1-1;
if (ro1<n+1)+(co1<n+1), 
	disp('Dimensions of first ellipsoid are incorrect');break;end;
if (ro2<n+1)+(co2<n+1), 
	disp('Dimensions of second ellipsoid are incorrect');break;end; 
 
%  Start the algorithm of covering the intersection by a convex
%  combination of the two ellipsoid and optimzing  for volume:
 
  Q1=inv(e1(2:n+1,1:n));a1=e1(2:n+1,n+1);
  Q2=inv(e2(2:n+1,1:n));a2=e2(2:n+1,n+1);
  [R,s,V]=svd(Q1);
  R=(R*s.^0.5)';
  R1=V*inv(s).^0.5;
  Q=R1'*Q2*R1;
  [U,d,V]=svd(Q);
  b=-U'*R*a1;
  A=U'*R;
  a=-U'*R*(a1-a2);
 
%  Calculate the minimizing  $\rho$ for the convex combination
%  of two ellipsoids:
 
  for i=1:501, 
    r(i)=0.002*i-0.002;
    lam=ones(n,1)*(1-r(i))+r(i)*diag(d);
    v=diag(d).*(a.^2);
    num=1.0-r(i)*sum(v)+r(i)*r(i)*sum(diag(d).*v.*lam);
    den1=prod(lam);
    den2=sum(lam);
    vol1(i)=num/den1;
    vol2(i)=num/den2;
  end;
 
  [y,j1]=min(vol1);
  rho=r(j1);
 
%  Transform back the equations:
 
  lam=ones(n,1)*(1-rho)+rho*diag(d);
  v=diag(d).*(a.^2);
  c=rho*diag(d).*a./lam;
  num=1.0-rho*sum(v)+rho*rho*sum(diag(d).*v./lam);
  Q3=inv(A'*diag(lam)*A/num);
  a3=R1*U*(c-b);
 
%  Form the output;
 
E=[1 ones(1,n);Q3 a3];
 
return;
