function [P1,acc]=fconvh(H,P,typ,spd);
%  FCONVH: compute the intersection of a polytope and a set of half-spaces
%  Inputs:
%    H[[1 1;-1 1]]   =  list of half-spaces
%    P[[0 eps;1 1;-1 1;-1 -1;1 -1]] = polytope
%     typ['numer']  = type of operation
%     speed = 1 if speed = 0 if memory is preferred
%  Outputs:
%    P1[[0 eps;1 1;-1 1;-1 -1;1 -1]] = polytope
%    acc[eps]  = maximum fitting error of adjacent vertices and facets
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Find the global error bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;global COMPLX;
 
%  Activate interface to set bounds if necessary:
 
if isempty(KAPPA) | isempty(DELTA), setdelta;end;
 
%  Diagnostics:
 
if nargin>1 & isempty(P), 
   disp('Warning: polytope was empty in UPDATE');
   return;
end;
 
%  Define the default of input variables:
 
if nargin<2,  
   P=[0 eps;1 1;-1 1;-1 -1;1 -1];
elseif nargin<1, 
   P=[1 1;-1 1];
end;
acc=eps;
if nargin<3, typ='numer';end;
if nargin>3, fastm=spd;else fastm=0>1;end;
 
   
%  Find dimension of space:
   
d=size(H,2)-1;
 
%  Set initial polytope to KAPPA hypercube if `P' is undefined:
 
if nargin<2, 
   e=ones(1,d); P=defbox(-KAPPA*e,KAPPA*e);
end;
 
%  Count number of half-space updates needed:
 
noh=size(H,1);[F,nf]=faces(P);
 
 
 if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('FCONVH started at %2i hrs %2i min %2.3f sec with %5i updates and %5i polytope faces...\n',cl(4:6),noh,nf);
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
 
%  Initialize polytope for updating procedure:
 
P1=P;
          
%  Perform updates recursively:
 
for k=1:noh
   [P1,acc]=update(H(k,:),P1,typ,fastm);
end;
 
%  Check whether global error bound is violated before exiting:
 
if acc>DELTA, warndel;end;
 
 
 if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('  FCONVH finished at %2i hrs %2i min %2.3f sec.\n',cl(4:6));
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
return;
   
      
      
      
      
   
   
   
