function [O,acc]=poladdi(O1,O2,dplus,typ,accur);
%  POLADDI: compute diamond inside the sum of two polytopes
%  Inputs:
%    O1[[1 eps;1 0]] = first polytope
%    O2[[1 eps;1 0]] = second polytope
%    dplus[0]        = number of vertices added to diamond
%    accur[0.001]    = accuracy requirement
%  Outputs:
%     O[[1 eps;1 0]] = generalised diamond insside the sum
%       acc          = max. error of vertex-facet adjacency
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Define default input:
 
if nargin<2, O2=[1 eps;1 0];end;
if nargin<3, dplus=0;end;
if nargin<4, typ='numer';end; 
if nargin<5, accur=0.001;end;
   
%  Set the global precision bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  Find out the number of points and dimension of space:
 
%  Diagnosis:
 
[nd,d1]=size(O1);[nd2,d2]=size(O2);d=d1-1;
if (d<1),
  disp('Dimension of object must be at least 1 in "poladdi.m".');  break;
end;
 
 
if (d~=d2-1),
  disp('Objects into "poladdi.m" are of different formal dimensions.');  break;
end;
 
%  Compute V = set of the sums of all combinations of vertices:
 
    [V1,nv1]=vertices(O1);[V2,nv2]=vertices(O2);
    nv12=nv1*nv2;
    V=zeros(nv12,d);
    for i=1:nv1,
      for j=1:nv2,
        k=(i-1)*nv2+j;V(k,:)=V1(i,:)+V2(j,:);
      end;
    end;
    
%  A generalised diamond is found in convex hull of V.
%  First the largest diameter is found with en points
%  `ds' and `de' , respectively:
 
   newV=[];
   [dl,ds,de,ids,ide]=diamet(V);
   newV=[ds';de']; % the vertex set of the diamond is initialised
   
%   The rest of the points is formed
   
   restV=setdiff(V,[ds';de'],'rows');
   S=ds-de;
   for i=1:d-1,
 
	   [U,D,V1]=svd(S);U1=U(:,i+1:d); % computing orthogonal transformation
	   lowV=restV*U1; % transforming the rest of the points
	   [dl,ds1,de1,ids1,ide1]=diamet(lowV); % diameter of point set
	   
      ds=restV(ids1,:)';
      de=restV(ide1,:)';
	   S=[S, ds-de];
	   
      newV=[newV; ds';de'];  % adding to vertex llist of diamond
      restV=setdiff(restV,[ds';de'],'rows'); % = the remaining poiints
	   
   end;	       
   
%  Compute the generalised diamond inside the sum:
   
  [O,acc]=convh(newV);
  
%  Include further points into the sum:
 
if nargin<3, return;end;
 
%  Compute Boolean array of vertices remaining outside:
 
Fs=faces(O);V=restV;nv=size(V,1);P=O;
ind=max(Fs*[V -ones(nv,1)]') > DELTA*ones(1,nv);
Vv=V(ind',:); % = array of vertices outside
[nvv,d]=size(Vv);
[V1,nv1]=vertices(P);
v=inf;
 
if nargin<5, accur=0;dplus=nv1;end;
 
%  Start recursion of including new points into the convex
%  one-by-one:
 
while (nvv>0)&(nv1<2*d+dplus)&(v>accur),
 
%  Compute the "most distant" point to be included:
 
vin=1;v=0;
for i=1:nvv,
	[v0,lvin]=max(Fs*[Vv(i,:), -1]');
	if v0>v, v=v0;vin=i;end;
end;
 
xn=Vv(vin,:); % = most distant point
 
%  Point 'xn' is included into the convex hull:
 
[P,ac]=p_conv(xn,P,typ);
if ac>acc,acc=ac;end; % fitting accuracy is updated
 
%  Check for points remaining outside:
 
[Fs,nf]=faces(P);
ind=max(Fs*[Vv -ones(nvv,1)]') > DELTA*ones(1,nvv);
Vv=Vv(ind',:);   % = array of vertices outside
nvv=size(Vv,1);  % update number of vertices outside
[V1,nv1]=vertices(P);
	
end; % end of adding the new point xn to the convex hull
O=P;
return;
