function volume=polvol(P)
%  POLVOL: compute the volume of a polytope
%  Inputs:
%    P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = polytope
%  Outputs:
%    volume[2]  =  volume of polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Set the global precision bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate the user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  Deal with special cases:
 
if isempty(P),volume=0;return;end;
[nf,d1]=size(P); d=d1-1; dact=dim(P);
if d<1,  volume=0;return;end;
if dact<d, volume=0;return;end;
 
%  Extract facet and vertex arrays:
 
if d>1,np=P(1,2); F=P(2:np+1,:); V=P(np+2:nf,1:d); nv=nf-np-1;end;
 
%  Start recursive computation of the volume (1D case treated first):
 
if d==1, 
   if P(1,1)==1, volume=0;return;else Ver=vertices(P);volume=max(Ver)-min(Ver);
   return;
   end;
%  the multi-dimensional case :
else
   vol=0;
   for i=1:np,
    
      n=F(i,1:d)';c=F(i,d+1);  % i-th facet:
      
      Fm=[F(1:i-1,:);F(i+1:np,:)]; % all the other facets 
      [N,s,v]=svd(n);
      if det(N)<0, N(:,d)=-N(:,d);end;
      
%  indices of vertices fitting to the i-th facet :
 
ind=abs([V -ones(nv,1)]*F(i,:)')<DELTA;
Vi=V(ind,:); % vertices fitting to the i-th facet
[nvi,di]=size(Vi);
      
%  Compute the facets in `Fm' with at least $d-1$ adjacent vertices in `Vi':
      
      indf=sum(abs([Vi -ones(nvi,1)]*Fm')<DELTA)>d-1.5;
      
%  Compute the set of facets adjacent to i-th facet :
      
      Fi=Fm(indf',:); 
      [nfi,di]=size(Fi);
      
%   Initialize of (d-1)-dimensional
%   facet list of the ith facet (subfacets):
      
      FF=zeros(nfi,di-1);
      
%   Construct the subfacet list :
      
      Vii=Vi*N;Vix=Vii(:,2:d);
      for j=1:nfi,
         F1=Fi(j,1:d)*N;
         nmr=norm(F1(2:d));
         FF(j,:)=[F1(2:d) Fi(j,d+1)-Vii(1,1)*F1(1)]/nmr;
      end;
      
%  Build up the facet polytope:
      
      PP=[0 nfi zeros(1,d-2);FF; Vix -ones(nvi,1)];
      vol=vol+c*polvol(PP); % adding the volume (area of the facet polytope)
      
   end;
vol=vol/d;
end;
 
volume=vol;
return;
