function E=sel(C,options);
%   SEL:  find the minimal volume ellipsoid around a set of points
%   Inputs:
%     C[-1;1]        =  array of points
%     options[[0.0001,150]]  =  ['termination tolerance', 'number of iterations']
%   Outputs:
%     E[[1 0;1 0]] = ellipsoid
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
 
%  Define default values:
 
if(nargin<2)options=[1.e-4,150];end;
 
%  Compute the Cholesky decomposition for the extended set of points `[C,1]':
 
[m,n]=size(C);C=[C,ones(m,1)];nA=n+1;
[R,p]=chol(C'*C);
 
%  Do diagnosis:
 
if(p>0),disp('Ellipsoid dimension is less than space dimension !');end;
 
 
%  Start optimization by successive space transformations:	
   
   if(p>0),ks=5*nA;else ks=nA;end;
   X=eye(nA);w=-0.7;
   for k=1:ks,
      [m1,i1]=max(sum((C.*C)'));z=C(i1,:)/sqrt(m1);
      C=C+w*(C*z')*z;X=X+w*(X*z')*z;
   end;
   for k=10:options(2),
      w=-1/k;[m1,i1]=max(sum((C.*C)'));z=C(i1,:)/sqrt(m1);
      C=C+w*(C*z')*z;X=X+w*(X*z')*z;
   end;
   [m1,i1]=max(sum((C.*C)'));X=X*X'/m1;
   Y=X\eye(nA);X=X(1:n,1:n)\eye(n);
 
%  Build up the solution of the original problem:
 
E=[1,zeros(1,n);X*(1-1/Y(nA,nA)),Y(1:n,nA)/Y(nA,nA)];
 
return;
 
