function [Totsurf,Totout,Totint]=sphsep(Sph,appord);
%  SPHSEP: compute the joining surface area of spheres
%  Inputs:
%    Sph[[1 0;1 0]] = array of spheres
%    appord[8]      = order of polygone approximation of circles
%  Outputs:
%    Totsurf[0] = total joining surface area
%    Totout[0]  = upper bound of joining surface area
%    Totint[0]  = lower bound of joining surface area
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Find the global numerical bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Define defaults, dimensions and number of spheres:
 
if nargin<2, appord=8;end;
d=size(Sph,2)-1;
nosph=size(Sph,1)/(d+1);
 
%  Include all the spheres in a large box:
 
rvecs=zeros(0,d);centS=zeros(nosph,d);radS=zeros(nosph,1);
 
for i=1:nosph,
 S=Sph((i-1)*(d+1)+1:i*(d+1),:);
 cS=ellcent(S);
 centS(i,:)=cS';
 C=ellicov(S);
 rS=sqrt(C(1,1));
 radS(i)=rS;
 rvecs=[rvecs;cS'+rS; cS'-rS];  
end;
BigBox=defbox(min(rvecs)-1,max(rvecs)+1);
 
%  Intialize of upper and lower bounds of surface estimate:
 
Totout=0;Totint=0;
 
%  Take each sphere on-by-one to compute  the joining surfaces
%  with other spheres:
 
for i=1:nosph,
 
%  The i-th sphere:
 
 S=Sph((i-1)*(d+1)+1:i*(d+1),:);
%  .. and its centre, covariance matrix and radius:
 cS=ellcent(S);C=ellicov(S);
 rS=sqrt(C(1,1));
 
%  Initialize variables related to boundary surfaces for the ith sphere:
 
    hspaces=zeros(0,d+1);
    normlist=zeros(0,d);
    Sph1=zeros(0,d+1);
 
 
%   Build up a list of half-spaces on the boundaries of which the
%   meeting surfaces lie with for the i-th sphere,
%   run j through the indices of all other wpheres:
 
   for j=1:nosph,
         Sj=Sph((j-1)*(d+1)+1:j*(d+1),:);
         cSj=ellcent(Sj);C=ellicov(Sj);
         rSj=sqrt(C(1,1));
         dist=norm(cSj-cS);
  
%  Test whether the ith and the j-th sphere are intersecting or not:
    
       if ~(i==j) & (rS+rSj)>dist,
%  Build up a list of normals for meeting surfaces:
         norml=(cSj-cS)/dist;
         normlist=[normlist;norml'];
%  Build up list of the intersecting spheres with the ith sphere:
         Sph1=[Sph1;Sj];
         lpos=(dist*dist+rS*rS-rSj*rSj)/2/dist;
         pos=lpos+norml'*cS;
%  Build up half-spaces:
         hspaces=[hspaces;norml' pos ];
       end;
   end;
 
%  The number of potential meeting surfaces:
 
   nointers=size(hspaces,1);
 
%  Compute a list of actual meeting surfaces:
 
   BigPol=BigBox;
   for j=1:nointers, 
     BigPol=update(hspaces(j,:),BigPol);
   end;
   facs=faces(BigPol);
 
%  Select into `intfacs' only those faces which are not due to outer boundig box:
 
   facB=faces(BigBox);
   intfacs=dif(facs,facB);
   nointf=size(intfacs,1);
   
%  Work in d-1 dimensional subspaces: to compute the
%  meeting surface elments:
  
   for j=1:nointf,
 
%  Pick the index of the meeting sphere:
 
       W=ones(size(normlist,1),1)*intfacs(j,1:d)-normlist;
       [w,k]=min(diag(W*W'));
 
%  Inequalities a'x<b in d-dimensions:
 
       a=intfacs(j,:);b=intfacs(j,d+1);
 
%  Pick the meeting sphere and it sarameters:
       Sk=Sph1((k-1)*(d+1)+1:k*(d+1),:);
       cSk=ellcent(Sk);
        C=ellicov(Sk);
       rSk=sqrt(C(1,1));
    
%  Compute the distance of the centres of the ith and the meeting sphere:
       dist=norm(cSk-cS);
       norml=(cSk-cS)/dist;
    
%  Compute the radius of th emeeting 'circle':
       
       x=(dist*dist+rS*rS-rSk*rSk)/2/dist;
       
%  Compute the centre of th emeeting circle:
       
       opos=cS+norml*x;
 
%  Build up the list of linear constrains in eth meeting hyperplane
 
       Prfacs=zeros(0,d);
       U=svd(norml);
       for n=1:size(facs,1),
         if ~(n==k),
         anew=facs(n,1:d)*U;anew=anew(2:d);
         bnew=facs(n,d+1)-facs(n,1:d)*opos;
         if norm(anew)>d*DELTA, Prfacs=[Prfacs;anew bnew];end;
         end;
       end;
     
%  Compute the d-1 dimensional meeting polytope:
  
      PrPol=fconvh(Prfacs);
      
%  Define the meeting 'circle':
 
       rInt=sqrt(rS*rS-x*x);
       cInt=defell(rInt*rInt*eye(d-1));
 
%  Approximate the meeting circle by a 'polygone':
 
       [Fout,Fint]=ellapprx(cInt,appord);
        Fout=faces(Fout);Fint=faces(Fint);
       
%  Intersect the meeting polytope with the appr. circle:
%  ...with an outer bound:
       Pout=PrPol;
       for m=1:size(Fout,1),
           Pout=update(Fout(m,:),Pout);
       end;
 
%  ... with an inner bound:
       Pint=PrPol;
       for m=1:size(Fint,1),
           Pint=update(Fint(m,:),Pint);
       end;
      
%  Addg the surface element to the total meeting surface:
%  ... to the outer bound:
       Totout=Totout+polvol(Pout);   
       
%  ... to the inner bound:
       Totint=Totint+polvol(Pint);
    end;  
end;
 
%   Deal with the extra surfaces for large number of spheres:
 
if nosph>d+1,
   
[C,nc]=combin(nosph,d+1);
 
Jpoints=zeros(0,d);
 
for i=1:nc,
 hspaces=zeros(0,d+1);
 for k=1:d,
  for j=k+1:d+1,
       dist=norm(centS(C(i,k),:)-centS(C(i,j),:));
       if (radS(C(i,k))+radS(C(i,j)))>dist,
    norml=(centS(C(i,j),:)-centS(C(i,k),:))/dist;
    lpos=(dist*dist+radS(C(i,k))*radS(C(i,k))-radS(C(i,j))*radS(C(i,j)))/2/dist;
         pos=lpos+norml*centS(C(i,k),:)';
         hspaces=[hspaces;norml pos ];
       end;
  end;
 end;
 
 if size(hspaces,1)==round(d*(d+1)/2),
 
  A=hspaces(:,1:d);b=hspaces(:,d+1);
  x=pinv(A'*A)*A'*b;
 
  if max(abs(A*x-b))<1000*DELTA, 
    bool=(1:d+1)<0;
    for k=1:d+1,
    if norm(x'-centS(C(i,k),:))<radS(C(i,k),:), bool(k)=1>0;end;
    end;
    if sum(bool)==d+1, Jpoints=[Jpoints;x'];end;
  end;
 
 end;
 
end;
 
if size(Jpoints,1)>d-1,
  Pc=convh(Jpoints);
  Xarea=surfarea(Pc);
  Totout=Totout+Xarea;
  Totint=Totint+Xarea;
end;
 
end;
 
Totout=Totout/2; % very conservative large upper bound
Totint=Totint/2; % very conseratove small lower bound 
 
 
 
Totsurf=(Totint+Totout)/2; % reasonable estimate
    
 
 
return;
        
