function [axout,p,ligh]=view3D(P,axin,style,pcolor);
%  VIEW3D: display 3D view of 3D polytope
%  Inputs:
%    P  = polytope
%    axin = axes in which polytope is to be displayed P
%    style['interp'] = style of rendering
%    pcolor = basic colour of the polytope
%  Outputs:
%    p     = handle of patch object of polytope
%   axout  = axes handle
%    ligh  = handle of light used
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  diagnostics check:
 
if P(1,1)>0, 
   error('VIEW3D only handles full dimensional 3D objects');end;
 
%  Finding the dimension of polytope representation-space
 
d=size(P,2)-1;
 
 
%  Assigning default rendering mode:
 
if nargin<3, style='interp';end;
 
%  Initialisation of  new plot:
 
if nargin<2, 
   figure;axin=newplot;view(3);axout=axin;
else 
 
%  Assigning axes "ax" for plotting:
 
   axes(axin);axout=axin;
end; 
 
%  Assigning default flat polytope color:
 
if nargin<4, pcolor=[0.9 0 0];end;
 
%  Extracting the vertices and facets:
 
[V,nv]=vertices(P); F=faces(P);
 
%  Extracting the face-vertex adjacency table:
 
FV=fv(P);
 
%  If "ax" was not definded then new camerapostion is set:
 
if nargin<2, 
 diam=diameter(P);cnt=mean(V);cnt
 set(axout,'CameraTarget',cnt);
 set(axout,'CameraPosition',cnt+diam*[-4.0657   -5.4502    4.8301]);
 campos=get(axout,'CameraPosition');
end;  
 
%  Computing the camera position:
 
campos=get(axout,'CameraPosition');
if intest(campos,P), error(' "CameraPsotion" was found inside the polytope by VIEW3D');end;
 
%  Computing the visible faces:
 
vFind=F*[campos -1]'>0;
 
%  Computing the vertex list to all facets:
 
FV=fv(P);
 
%  Computing the vertex list fitting to visible faces:
 
vF=FV(vFind,:);
 
%  Counting the number of visible facets:
 
[novf,maxnov]=size(vF);
 
%  Computing Boolean vector of visible vetices:
 
Vin=(1:nv)'<0;for i=1:novf, for j=1:maxnov, Vin(vF(i,j))=1>0; end;end;
 
%  Forming the list of visble vertices:
 
vV=V(Vin,:);
 
%  Computing reindexing table for visible vertices:
 
newind=zeros(nv,1);if Vin(1), newind(1)=1;else newind(1)=0;end;
for k=2:nv, newind(k)=newind(k-1)+Vin(k);end;
 
%  Reindexing the vertices in the visible facet-vertex table:
 
for i=1:novf, for j=1:maxnov,
   if vF(i,j)>0, vF(i,j)=newind(vF(i,j));end;
end;end;
 
%  Defining the flat polytope colour:
 
if strcmp(style,'flat'), tcolor=ones(novf,1)*pcolor;
   else tcolor=ones(size(vV,1),1)*pcolor;end;
   
%  Defining patch of visible faces:
 
p=patch('faces',vF,'vertices',vV,'Facecolor',style,...
      'CData',tcolor,'FaceVertexCData',tcolor);
   
%  Definig a light object:
 
set(0,'DefaultfigureRenderer','zbuffer');
ligh=light('Position',[0.7*campos(1) campos(2) 0.8*campos(3)]);   
 
%  Setting the face lighting:
 
set(p,'facelighting','gouraud');  
 
%  Setting perspective view:
 
set(axout,'Projection','perspective');
 
%  Setting ambient light color:
 
set(axout,'ambientlightcolor',[1 1 1 ]);
return;
 
 
  
