function [flag] = mp_PlotPoly(Poly, ax, lin, alp, col, lincol,linew, lqrc)
% SYNTAX: [flag] = mp_PlotPoly(Poly, ax, lin, alp, col, lincol)
%
% Plots a convex polytope in 2D or 3D.
%
% Input: - Polytope: Poly=[A b] => {x|Ax<=b}
% Optional Inputs:
%        - ax: [xmin xmax ymin ymax zmin zmax]
%        - lin: 0/1 lines between adjacent vertices. Default: 1
%        - alp: [0, 1] alpha setting for the faces. Default: 0.3
%        - col: color of the face. Default: blue.
%        - lincol: color of the lines: Default: blue.
%        - linew = linewidth  
%        - lqrc = use cdd to compute vertices.           
% Output: none.

global KAPPA;global ERRFACTOR; global  MAXSIZE;
KAPPA=500; ERRFACTOR=100; MAXSIZE=8e6;
flag=1;
warning off MATLAB:break_outside_of_loop

if nargin < 8 | isempty(lqrc)
    lqrc = 0;
end
if isstruct(Poly)
    Poly=Poly.ineqs;
end
if 1
    v=lqrcVertices(Poly)';
    P=convh(v);
else
    P=fconvh(Poly);
end
%P=convh(rand(90,3));

Pdim=size(Poly,2)-1;
try,
    [d]=intpoint(P);
    if isempty(d)
        error('Polytope is empty')
    end
catch
    error('Polytope is empty or Geometric Bounding Toolbox is not in the path')
end



if nargin < 7| isempty(linew)
    linew = .1;
end
if nargin < 6 | isempty(lincol)
    lincol = 'k';
end
if nargin < 5 | isempty(col)
    col = 'b';
end
if nargin < 4 | isempty(alp)
    alp=.3;
end
if nargin < 3 | isempty(lin)
    lin=1;
end
if nargin < 2
    % [vmin,vmax]=ranges(P)
    ax=[];
end

% Find the vertices of the polytope.
V=vertices(P);
% Find the Vertex-Vertex adjacency table and the Facet-Vertex adjacency
% table.
[Vtable,Ftable]=vvf_2(P);
%Pdim=3;
% 2 dimensional polytope
if Pdim==2
    % Find a path following the edges from startnode to pivotnode.
    startNode=1;
    pivotNode=Vtable(1,end);
    % Path starts at starNode
    path(1)=startNode;
    currentNode=startNode;
    prevNode=startNode;
    % Construct the path
    for i=2:size(V,1)-1
        % Find next node in path, which is a neighbor of currentnode, but
        % not the previous node and not the pivotnode.
        next=Vtable(currentNode,Vtable(currentNode,:)~=pivotNode & Vtable(currentNode,:)~=prevNode);
        path(i) = next;
        currentNode = next;
        prevNode = path(i-1);
    end
    % Node i, i+1 in path and pivotNode defines a polygon, such that all
    % polygons are non-intersecting.
    for i=1:length(path)-1
        patch(V([path(i) pivotNode path(i+1)],1),V([path(i) pivotNode path(i+1)],2),...
            col,'EdgeColor','none'),alpha(alp),if ~isempty(ax) axis(ax); end;
    end
    if lin
        for i=1:size(Vtable,1)
            nonZero=Vtable(i,find(Vtable(i,:)>0));
            for j=1:length(nonZero)
                x=V([i Vtable(i,j)],1);
                y=V([i Vtable(i,j)],2);
                hold on
                line(x,y,'Color',lincol,'LineWidth',linew)
            end
        end
    end

    % 3 dimensional polytope
elseif Pdim==3
    % Create the Facet-Vertex adjacency table.
    FVTable=fv(P);
    % some of the faces are not polygons
    if size(FVTable,2)>3
        % Find the faces which are polygons.
        threeNFaces = FVTable(find(FVTable(:,4)==0),1:3);
        % Find the faces which are not polygons.
        threePlussFaces = FVTable(find(FVTable(:,4)>0),:);
        % Divide all faces that are not polygons into non-intersecting
        % polygons.
        for j=1:size(threePlussFaces,1)
            % Face to divide into polygons.
            currentFace=threePlussFaces(j,:);
            currentFace=currentFace(find(currentFace>0));
            % First node in path from startnode to pivotnode
            startNode=currentFace(1);
            % Find neighbors to startnode, which is in the current face.
            neighbInface = Vtable(startNode,find(ismember(Vtable(startNode,:),currentFace)));
            pivotNode=min(neighbInface);
            path=[];
            path(1)=startNode;
            currentNode=startNode;
            prevNode=startNode;
            % Build the path from startNode to pivotNode.
            for i=2:size(currentFace,2)-1
                next=Vtable(currentNode,Vtable(currentNode,:)~=pivotNode & Vtable(currentNode,:)~=prevNode &...
                    ismember(Vtable(currentNode,:),currentFace));
                path(i) = next;
                currentNode = next;
                prevNode = path(i-1);
            end
            % Node i, i+1 in path and pivotNode defines a polygon, such that all
            % polygons are non-intersecting.
            for i=1:length(path)-1
                patch(V([path(i) pivotNode path(i+1)],1),V([path(i) pivotNode path(i+1)],2),...
                    V([path(i) pivotNode path(i+1)],3),col,'EdgeColor','none'),alpha(alp),grid, if ~isempty(ax) axis(ax); end;
            end

        end
        H.Faces=threeNFaces;
        H.Vertices = V;
        patch(H,'FaceColor',col,'EdgeColor','none');alpha(alp);grid;if ~isempty(ax) axis(ax); end
    else % All faces are polygons.
        H.Faces=FVTable;
        H.Vertices = V;
        patch(H,'FaceColor',col,'EdgeColor','none'),alpha(alp),grid,if ~isempty(ax) axis(ax); end
    end
    % Plot the wireframe of the polytope.
    if lin
        for i=1:size(Vtable,1)
            nonZero=Vtable(i,find(Vtable(i,:)>0));
            for j=1:length(nonZero)
                x=V([i Vtable(i,j)],1);
                y=V([i Vtable(i,j)],2);
                z=V([i Vtable(i,j)],3);
                hold on
                line(x,y,z,'Color',lincol);
            end

        end
    end
else
    error('Handles 2D and 3D polytopes only')
end



