function [Pout,Pin]=ellapprx(e1,nord);
%   ELLAPPRX: compute a polytope approximation to a given ellipsoid
%  Inputs:
%   e1[[1 0;1 0]]  = ellipsoid
%   nord[2] = number of approximations in each dimension
%  Outputs:
%   Pout[ [0 eps;1 1;-1 1;-1 -1;1 -1] ]  = tight outer bounding polytope
%   Pin[ [0 eps;1 1;-1 1;-1 -1;1 -1] ]  =  tight inner bounding polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Define defaults:
 
if nargin<2, nord=2;elseif nargin<1, e1=[1 0;1 0];end;
Pout=[0 eps;1 1;-1 1;-1 -1;1 -1];
Pin=[0 eps;1 1;-1 1;-1 -1;1 -1];
 
%  Dimension of the space :
 
  n=size(e1,2)-1;
 
%  Compute points on the surfaces of the ellipsoid :
 
  v=dirgen(n,nord); v=v(:,(n:-1:1)); % v = directions generated
  P1=ellicov(e1);[Q1,D1]=eig(P1);d1=sqrt(D1);
  c1=ellcent(e1)'; T1=v*d1*Q1';
  T=T1+ones(size(v,1),1)*c1;  % T = set of points on ellipsoid  surface
  [t1,d0]=size(T);   
    
%  Compute convex hull of the surface points in $T$ :
 
  Pin=convh(T);
  
%  Compute tangent planes to the ellipsoid at points in $T$:
 
  H1=ones(t1,n+1);
  for i=1:t1, 
    fi=T1(i,:)/P1;
    H1(i,1:n+1)=[fi fi*(T1(i,:)+c1)'];
  end;      
 
%  Compute the range of the surface points and surrounding them
%  by an axis aligned box
 
[mie,mae]=ellrange(e1);Pout=defbox(mie,mae);
 
%  Start polytope updating from the range box
%  to obtain the outer bounding polytope to the ellipsoid:
 
Pout=fconvh(H1,Pout);
return
 
