function [vmax,vmin,width]=elldrxt(G,di);
%  ELLDRXT:  compute extremal points of an ellipsoid in given direction
%  Inputs:
%   G[[1  0;1 0]] = ellipsoid
%   di[1]          = direction vector
%  Outputs:
%   vmax[1]    = extremum in + direction
%   vmin[-1]    = extremum in - direction
%   width[2]   = the width in the direction
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Set default values:
 
vmax=1;vmin=-1;width=2;if nargin<2, di=1;end;
  
%  Treat the 1D case:
 
 if size(di,1)==1, di=di';end;
 
%  Extract the ellipsoid covariance $C$ and centre $c$:
 
 C=ellicov(G); c=ellcent(G);
  
%  Compute the extreme points by the formula $c\pm Cd_i/(1+d_i^TCd_i)$
%  for direction vector $d_i$. The extreme points in $d_i$ direction are
%  $ v_{max} $ and  $v_{min}$ :
 
lam=1/sqrt(di'*C*di);
v=lam*C*di; vmin=c-v;vmax=c+v;
 
%  Compute the width of the ellipsoid  as $w=d_i(v_{max}-v_{min})/\|d_i\|$ :
 
width=abs(di'*(vmax-vmin)/sqrt(di'*di));
 
  return;
  
