function [V1,B1]=findsimp(V);
%  FINDSIMP: find largest (d-1)-dimensional simplex from a set of points
%  Inputs:
%    V  = set of d-dimensional points
%  Outputs:
%   V1  = set of points spanning (d-1)-dimensional simplex
%   B1  = Boolean vector to say which oints are selected from `V' for the simplex
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Initialize variables:
 
global DELTA;global KAPPA;global ERRFACTOR;
[nv,d]=size(V);
B1=ones(nv,1)<0;
 
if nv==1, V1=V;B1=1>0;return;end;
if nv==2 & d>=2, V1=V;B1=[1>0;1>0];return;end;
if nv==2 & d==1, V1=V(1,:);B1=[1>0;0>1];end;
    
%  Find a large initial diameter:
 
  diam=0;
  for i=1:nv,
     for j=1:nv,
        di=norm(V(i,:)-V(j,:));
        if di>diam, diam=di;ci=i;cj=j;end
     end;
  end;
  ds=V(ci,:)';B1(ci)=1>0;
  de=V(cj,:)';B1(cj)=1>0;
  
 
%  Start procedure of finding a large initial simplex starts:
  
V0=[ds';de']; % = initial set of vertices of the simplex
Vx=V-ones(nv,1)*ds'; % = relative positions of V
  
%  Initialize the dimension and Boolean value
%  of the lower dimensional case:
  
  lowdim=d;  % = value of lower dimension
  lowd=0>1; % = 1 of lower dimension
 
%  Add vertices one-by-one to build up the simplex:
nov=2;
for n=2:d,
  if ~lowd,
     A=V0(2:n,:)-ones(n-1,1)*ds'; 
     A1=eye(d)-A'*pinv(A*A')*A;  % = projection matrix
     k=1;ma=0; % initialize vertex index and max. distance
     for t=1:nv, 
       dist=Vx(t,:)*A1*Vx(t,:)'; % = distance from V0
       if ma < dist, ma=dist; k=t; end; % update
     end;
      
     if ma<DELTA,   % detection of lower dimensional case
        lowdim=n-1; % setting Boolean and numerical values
        lowd=1>0;
     end;
     
     if ~lowd,
        V0=[V0;V(k,:)];nov=nov+1;if nov<d+1,B1(k)=1>0;end;
     end;
  end;
end;
 
if lowdim+1>d,
    lowdim=d-1;
    
end;
 
V1=V0(1:lowdim+1,:);
 
return; 
