function [a,b,fitacc]=planfit(V);
%  PLANFIT: fit a hyperplane to a set of points
%  Inputs:
%      V  = set of points
%  Outputs:
%    a   = left hand side of linear equation
%    b   = right hand side of linear equation
%    fitacc = maximum fitting error equation to points
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Find global numerical bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate interface if any of the bounds is undefined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;P=[];end;
 
%  Compute the vectors relativ to the first point:
 
[nv,d]=size(V);
V1=V(2:nv,:)-ones(nv-1,1)*V(1,:);
 
%  Compute the singular value decomposition of the relative vector set:
 
[U,S,L]=svd(V1);
 
%  The right and left hand sides of the equation:
 
a=L(:,nv)';b=mean(V*a');
 
%  Compute the maximum fitting error:
 
fitacc=max(abs(V*a'-b*ones(nv,1)));
return;
