function [O,acc,FVnew]=p_conv(xn,P,typ,FV);
%  P_CONV: include a point into a convex hull polytope
%  Inputs:
%     xn[0]  = point
%     P[[1 eps;1 0]] = polytope
%     typ['numer']  = type of operation
%     FV   =  facet-vertex adjacency table if available
%  Outputs:
%     O[[1 eps;1 0]] = convex hull updated
%     acc[eps]       = worst-case accuracy of fits
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
if nargin<2, P=[1 eps;1 0];elseif nargin<1 xn=1;end; 
if size(xn,2)==1, xn=xn';end;
if nargin<3, typ='numer';end;
 
 
global DELTA;global KAPPA;global ERRFACTOR;global COMPLX;global MAXSIZE;
 
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;P=[];end;
acc=fvfitacc(P);if acc>=DELTA,warndel;end;
arrsize(P);
 
 
 if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('   P_CONV started at %2i hrs %2i min %2.3f sec with %5i facets of the polytope.\n',cl(4:6),P(1,2));
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
 
 
[xn,acc]=vadjust(xn,P,typ);
 
 
acc=fvfitacc(P);if acc>=DELTA,warndel;end;
 
 
d=size(P,2)-1;
[F,nf]=faces(P);
[V,nv]=vertices(P);
vcentre=mean(V);
 
 
indprop =  F*[xn -1]' > DELTA*ones(nf,1); 
if sum(indprop)<0.5, O=P;return;end; % testing for non-increase 
Fprop=F(indprop,:);h=-Fprop(1,1:d)';
indf=(1:nf)';
indProp=indf(indprop);
noprop=size(Fprop,1);
noprop=length(indProp);
 
 
 
indvis = F*[xn -1]' > -DELTA*ones(nf,1); 
Fvis=F(indvis,:);
 
 
if nargin<4, FV=fv(P);end;arrsize(FV);  
 
 
indf=(1:nf)'; 
indFvis=indf(indvis);    % indices of visible facets
nofvis=length(indFvis);  % no of visible facets
vvisF=FV(indvis,:);      % vertex lists of visible facets
vvproF=FV(indProp,:);
 
nindFvis=indf(~indvis);     % indices of non-visible facets
nofnovis=length(nindFvis);  % no non-visible facets
vnvisF=FV(nindFvis,:);      % vertex listsof not visible facets
 
 
visvtx=[];
for i=1:nofvis, visvtx=union(visvtx,vvisF(i,:));end;
 
 
relf=zeros(nofnovis,1)>ones(nofnovis,1);
relvtx=(1:nv)';relvtx=relvtx(~visvtx,:);
for i=1:nofnovis, 
   relf(i)=~isempty(intersect(visvtx,vnvisF(i,:)));
   relvtx=union(relvtx,vnvisF(i,:));
end;
vnvisF=vnvisF(relf,:);nofnovis=size(vnvisF,1);
 
 
subhyps=[];
for i=1:noprop,
  f=vvproF(i,:);
  for j=1:nofnovis,
     subhyp=intersect(f,vnvisF(j,:));
     if ~isempty(subhyp),
        if subhyp(1)==0, subhyp=subhyp(2:length(subhyp));end;
     end;
     if length(subhyp)>d-2,
        l0=size(subhyps,2);l1=size(subhyp,2);
        if l0>l1, subhyp=[subhyp zeros(1,l0-l1)];end;
        if l0<l1, subhyps=[subhyps zeros(size(subhyps,1),l1-l0)];end;
        if isempty(subhyps), subhyps=zeros(0,l1);end;
        subhyps=union(subhyps,subhyp,'rows');  
     end;
  end;
end;
 
nosubs=size(subhyps,1);
 
 
 
newF=ones(nosubs,d+1);
for i=1:nosubs,
   vts=subhyps(i,:); 
   while (vts(length(vts))==0) & (length(vts)>1), vts=vts(1:length(vts)-1);end;
   Vtx=V(vts',:);
   [a,b,ac]=planfit([xn;Vtx(1:d-1,:)]);
    if (a*vcentre'-b)>0, a=-a;b=-b;end;
   newF(i,:)=[a b];if ac>acc, acc=ac;end;
end;
 
 
oldfac=setdiff((1:nf),indProp);
oldF=F(oldfac,:);
F=[oldF;newF];
 
 
 
cancV=setdiff(visvtx,relvtx);
oldvtx=setdiff((1:nv),cancV);
V=[V(oldvtx,:);xn];
 
 
if nargin>3,
   oldFV=FV(oldfac,:);nvn=size(V,1);[noF,nov]=size(oldFV);
   mask=zeros(1,nv);
   oldvtxi=mask>ones(1,nv)
   oldvtxi(oldvtx)=ones(1,nvn-1)
   for i=1:nv, mask(i)=sum(oldvtxi(1:i));end; 
   mask
   for i=1:noF,
      nozer=oldFV(i,oldFV(i,:)>0);
      newrow=mask(nozer);newrow=newrow(newrow>0);
      nl=length(newrow);
      oldFV(i,:)=[newrow, zeros(nov-nl)];
   end;
   I=newF*[V -ones(nvn,1)]';
   nhnew=size(newF,1);
   Ind=abs(I)<DELTA*ones(nhnew,nvn); 
   vmax=max(sum(Ind'));indx=(1:nvn);
   FVnew=zeros(nhnew,vmax);
   for i=1:nhnew, 
      vf=indx(Ind(i,:));
      noh=size(vf,2);
      FVnew(i,1:noh)=vf;
   end;
   [norows,ovmax]=size(oldFV);
   if ovmax==vmax,
      FVnew=[oldFV;FVnew];
   elseif ovmax<vmax,
      FVnew=[oldFV zeros(norows,vmax-ovmax);FVnew];
   else
      FVnew=[oldFV;FVnew zeros(nhnew,ovmax-vmax)];
   end;
 end;
 
 
 
[nf,d1]=size(F);
[nv,d]=size(V);
O=[0 nf acc zeros(1,d-2);F;[V -ones(nv,1)]];
arrsize(O);
 
 
 if acc>DELTA, warndel;end;
 
 
 if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('     P_CONV finished %2i hrs %2i min %2.3f sec.\n',cl(4:6));
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
return;
