function [axout,ellip,ligh]=view3del(E,axin,style,resol);
%  VIEW3DEL: display 2D views of ellipsoids
%   Inputs:
%     E[[1 0 0 0; 1 0 0 0;0 1 0 0;0 0 1 0]] = ellipsoid
%     axin      =  object handle of axes
%   style['smooth']  = texture of surface ('smooth' or 'mesh')
%     resol[100]     = resolution of surface plot
%   Outputs:
%     axout  =  axes handle
%     ellip  =  object handle of ellipsoid surface
%     ligh   =  light handle
%  
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Default values:
 
if nargin<4, resol=30;end;
if nargin<2, axin=newplot;axout=axin;view(3);end;
if nargin<3, style='smooth';end;
if style(1:4)=='mesh', style='mesh  ';end;
 
%  Diagnosis of cases:
 
axes(axin);
if nargin>1, hold on; else hold off;end;
if nargout>0, axout=axin;end;
 
%  Extracting covariance and centre:
 
Ec2=sqrtm(ellicov(E));
ce=ellcent(E);n=resol;
 
%  Defining a spherical surface for the 3D ellipsoid:
 
[X,Y,Z]=sphere(n-1);
xx=zeros(n,n);yy=zeros(n,n);zz=zeros(n,n);a=(1:3)';
	for i = 1:n,
	    for j = 1:n,
	        a(1)=X(i,j);
	        a(2)=Y(i,j);
	        a(3)=Z(i,j);
		xxx=Ec2*a;
		xx(i,j)=xxx(1)+ce(1);
		yy(i,j)=xxx(2)+ce(2);
		zz(i,j)=xxx(3)+ce(3);
	    end;
	end;
 
%  Defining the style options and plotting surfaces:
 
 if (style == 'smooth' )
      ellip=surfl(xx,yy,zz);
	elseif (style == 'mesh  ' )
		ellip=mesh(xx,yy,zz);
	else
		disp('Style must be either "smooth" or "mesh".');
		break; 
   end;
   
%  Defining the rendering and color options:
   
   set(0,'DefaultfigureRenderer','zbuffer');
   set(ellip,'facelighting','gouraud');
   set(ellip,'CDataMapping','direct');
   shading interp;
   
%  Defnining the light direction:
  
   [az,el]=view;az=az/180*pi;el=el/180*pi;
   povec=get(gca,'cameraposition');
   povec(3)=2*povec(3);
   povec(2)=1.5*povec(2);
   set(light,'position',povec);
   ligh=light;
   return;
