function [VV,VF,nv,nh]=vvf(H);
%  VVF: produce a vertex-vertex and vertex-facet adjacency tables (version no. 2)
%  Inputs:
%      H  = polytope
%  Outputs:
%     VV  = vertex-vertex adjacency table
%     VF  = vertex-facet adjacency table
%     nv  = number of vertices
%     nh  = number of facets
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  Setting dimensions:
 
[nH,d]=size(H);if d>2,d=d-1;end;
 
%  Listing the faces and vertices:
 
[F,nh,ne]=faces(H);[V,nv]=vertices(H);
ne=H(1,1);
 
%  Constructing the vertex-facet adjacency Boolean table `I':
 
nh=nh+2*ne;indx=(1:nh)';VF=[];
for i=1:nv,
   I=F*[V(i,:), -1]';
   Ind=abs(I)<DELTA*ones(nh,1);
   vf=indx(Ind);
   noh=size(vf,1);
   [sr,sz]=size(VF);
   if noh<=sz, 
       VF=[VF;vf' zeros(1,sz-noh)];
   else
       VF=[VF zeros(sr,noh-sz);vf'];
   end;
end;
 
%  Constructing the vertex-vertex adjacency list (VV) :
 
VV=[];indxv=(1:nv)';
for i=1:nv,
    IndV=zeros(nv,1)<0;
    for j=1:nv,
        if i~=j, 
            intsc=intersect(VF(i,:),VF(j,:));intsc=setdiff(intsc,0);
            IndV(j)= (length(intsc) > d-ne-1.1) ;
        end;
    end;
    vv=indxv(IndV);
    nov=length(vv);
    [sr,sz]=size(VV);
    if nov<=sz,
        VV=[VV;vv' zeros(1,sz-nov)];
    else
        VV=[VV zeros(sr,nov-sz);vv'];
    end;
end;
return
   
 
