function [e,p,v]=ELLADDE(e1,e2,rin);
%  ELLADDE: compute outer bounding ellipsoid to the sum of two ellipsoids.
%  Inputs:
%    e1[[1 0;1 0]] = first ellipsoid
%    e2[[1 0;1 0]] = second ellipsoid
%     rin['vol']   = criterion (options: rin>0,'vol','tr1',tr2')
%  Outputs:
%    e[[1 0;4 0]]  = outer bounding ellipsoid of the sum
%    p  =  optimisation parameter received
%    v  =  criterion value optimised
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Defaults are defined:
 
if nargin<3, rin='vol';elseif nargin<2, e2=[1 0;1 0];
elseif nargin<1, e1=[1 0;1 0];end;
e=[1 0;4 0];
 
 
%    Diagnosis:
 
[ro1,co1]=size(e1);[ro2,co2]=size(e2);v1=[];v2=[];
if [ro1 co1]~=[ro2 co2], 
  disp('Dimensions of ellipsoids are different.');
  break; 
end;
if isstr(rin) & rin ~= 'vol' & rin ~= 'tr1' & rin ~= 'tr2' 
	disp('Incorrect parameter string.');
	break; 
end;
if ~isstr(rin) & (rin <=  0) ,
	disp('Incorrect parameter value.');
	break; 
end;
 
 
%     Start of algorithm to add two ellipsoids:
 
n=ro1-1;
Q1=e1(2:ro1,1:n);a1=e1(2:ro1,co1);
Q2=e2(2:ro1,1:n);a2=e2(2:ro1,co1);
Q=Q1/Q2;
lam=eig(Q);
r1   = sqrt(min(lam));
r2   = sqrt(max(lam));
 
%  Start of the minimal volume optimisation:
 
if rin == 'vol',
	
%  Calculating parameter `p' for minimal volume.
%  The polyomial `p' is the derivative of the criterion:
 
	x=-diag(lam(2:n));p=poly(x);
	for i=2:n-1, 
  		p=p+poly(-diag([lam(1:i-1) lam(i+1:n)])); 
	end;
	p=p+poly(-diag(lam(1:n-1)));p=conv(p,[0 1 1]);
	x=-diag(lam);p=p-n*[poly(x) 0];
	r=roots(p);
	r0=r(1);
	for i=1:n+1, 
  		if r(i)>0, 
    			r0=r(i); 
  		end; 
	end;
	r0 = 1/r0;
	v0 = det((1+1/r0)*Q1+(1+r0)*Q2);
elseif rin == 'tr1',
	
%  Calculate parameter for minimal trace:
 
	r0 = sqrt(trace(Q1)/trace(Q2)); 
	v0 = trace((1+1/r0)*Q1+(1+r0)*Q2);
elseif rin == 'tr2',
	
%  Calculate parameter for minimal trace of square:
 
	gam11 = trace(Q1*Q1);
	gam12 = trace(Q1*Q2);
	gam22 = trace(Q2*Q2); 
	trq2  = roots ([gam22 gam12 -gam12 -gam11]); 
	if     imag(trq2(1)) == 0 
		r0 = trq2(1);
	elseif imag(trq2(2)) == 0 
		r0 = trq2(2);
	else   
		r0 = trq2(3);
	end;
	v0  = trace(((1+1/r0)*Q1+(1+r0)*Q2)^2);
elseif ~(isstr(rin)) & rin > 0 ,
	r0 = max ([r1 rin]);
	r0 = min ([r2 r0 ]);
	v0 = 0;
	v1 = 0;
	v2 = 0; 
end;
 
%   Building output ellipsoid:
 
a=a1+a2;
Q=(1+1/r0)*Q1+(1+r0)*Q2;
e=[1 ones(1,n);Q a];
p=[r0 r2 r1];
v=[v0 v2 v1];
return
 
 
 
