function [E,P]=ELLINT(e1,e2,nord);
%  ELLINT: compute an ellipsoid around the intersection of two ellipsoids
%  Inputs:
%    e1[[1 0;1 0]] = first ellipsoid
%    e2[[1 0;1 0]] = second ellipsoid
%    nord[2]       =  order of approximation in each dimension
%  Outputs:
%     E[[1 0;1 1]] = ellipsoid around the intersection
%     P            = approximate polytope around the intersection
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%   Set defaults:
 
if nargin<4, nord=6;end;
if nargin<3, method=2;end;
if nargin<2, e2=[1 0;1 0];end;
if nargin<1, e1=[1 0;1 0];end;
E=[1 0;4 0];P=[0 eps;1 1;-1 1; -1 -1; 1 -1];
 
%  Input diagnostics:
 
if (e1(1,1)~=1), 
	disp('First object is not an ellipsoid');break; end;
if (e2(1,1)~=1), 
	disp('Second object is not an ellipsoid');break;end;
[ro1,co1]=size(e1);[ro2,co2]=size(e2);n=co1-1;
if (ro1<n+1)+(co1<n+1), 
	disp('Dimensions of first ellipsoid are incorrect');break;end;
if (ro2<n+1)+(co2<n+1), 
	disp('Dimensions of second ellipsoid are incorrect');break;end; 
 
%  Compute outer polytope approximations to each ellipsoid
%  (this can be modified to inner bounding polytopes if necessary):
  
Po1=ellapprx(e1,nord);Po2=ellapprx(e2,nord);
 
%  Put the half-space constraints together:
 
H=[faces(Po1);faces(Po2)];
 
%  Approximate polytope around the intersection:
  
[mie1,mae1]=ellrange(e1);[mie2,mae2]=ellrange(e2);
P=defbox(min([mie1;mie2]),min([mae1;mae2]));
P=fconvh(H,P);
 
%  Compute a covering ellipsoid around this polytope:
 
V=vertices(P);E=sel(V);
return
 
 
