function [F,nh,ne]=faces(P);
%  FACES:  extract half-space inequalities of polytope
%  Inputs:
%     P[1 0;1 1] = polytope
%  Outputs:
%    F   =  list of half-space inequalities with equalities twice listed
%    nh  =  number of proper half-space inequalities
%    ne  =  number of equalities
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Define default values :
 
if nargin<1, P=[1 0;1 1];end;
ne=P(1,1);if size(P,1)<1, F=[],nh=0;return;end;
 
%  Find dimensions:
 
[pr,pc]=size(P);if (pc<2),
   disp('Dimension or object type is wrong in "faces.m".');return;
end;
 
%  Deal with the case of higher dimensions >1. The equalities
%  are listed twice with opposite sign normals:
 
if pc>2,
  nh=P(1,2);
  F=[P(2:1+P(1,1),:);-P(2:1+P(1,1),:);P(1+P(1,1)+1:1+P(1,1)+nh,:)];
end;
 
%  Deal with dimensions 1 and 0. The equalities
%  are listed twice with opposite sign normals:
 
if pc<=2,
   if P(1,1)<0.1,F=P(2:3,:);nh=2;end;
   if P(1,1)==1,F=[P(1,:);-P(1,:)];nh=2;end;
end;
 
%  Compute the number of proper inequalities:
 
nh=size(F,1)-2*ne;
return;
 
