function [fac,P1]=facet(P,plno); 
%  FACET: compute the polytope of a facet in lower dimension
%  Inputs:
%    P[[1 0;1 0]] = polytope
%    plno[1]      = index of facet
%  Outputs:
%    fac[0] = facet polytope in lower dimension
%    P1[0]        = same dimensional facet polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Default value:
 
if nargin<2, plno=1;end;
 
%  Diagnostics:
 
if P(1,1)>0, 
   disp('Polytope into FACET must be full dimensional!');break;
end;
 
%  Find the dimension of the representation and dealing with 1D:
 
d=dim(P);if d==1, fac=0;P1=[1 0;1 0];return;end;
 
%  Find the neighbouring facet and vertex lists to facet no. `plno':
 
[plist,vlist]=planeigh(P,plno);
 
%  Extract the facets and vertices of `P':
 
F=faces(P);V=vertices(P);
 
%  List the vertices neighboouring facet `plno':
 
newV=V(vlist',:);
 
%  Find the inequality of facet `plno' and lsiting the neighbouring facets:
 
pl=F(plno,:);F1=F(plist,:);
 
%  Build up the polytope representation of the facet in same dimension $d$:
 
P1=[1 length(plist) P(1,3) zeros(1,d-2);pl;F1;newV -ones(size(newV,1),1)];
 
%  Compute a representation of the facet in its actual dimension:
 
fac=mindim(P1);
return;
 
