function P2=gbt627(P);
%  GBT627:  convert from GBT 6.1 formats to GBT 7.0 format
%  Inputs:
%    P[[2 2; 1 1; -1 1;-1 -1; 1 -1;2 0;1 0;2 0;1 0]] = polytope
%  Outputs:
%    P2[[0 eps; 1 1; -1 1;-1 -1; 1 -1]] = polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Find the global numerical bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate interface if any of the bounds is undefined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;P=[];end;
 
%  Perform the boundedness diagnostics:
 
if ~bounded(P), 
   disp('Polyhedron into GBT627 is not bounded.')
   disp('Cannot convert into "type 0" format.');break
end;
 
%  Find the dimension, number of facets and vertices:
 
d=size(P,2)-1;
nh=P(1,2);if d>1, nv=P(1,3);else nv=2;end;
 
%  Convert into type 2 format:
 
P=P(1:1+nh+2*nv,:);P(1,1)=2;
 
%  Extract and testing facets for ill-conditioning:
 
H=P(2:1+nh,:);
for i=1:nh, n=norm(H(i,1:d));
   if n>1000*eps,H(i,:)=H(i,:)/n;else error('Some faces are ill-defined in the input polytope to GBT627!'); end;
end;
 
%  Extract the vertex list and vertex-hyperplane adjacency table:
 
V=P(2+nh:1+nh+nv,1:d);
VH=P(2+nh+nv:1+nh+2*nv,1:d);
 
%  Compute largest fitting error:
 
fitacc=0;
for i=1:nv,
   ac=max(abs([V(i,:) -1]*H(VH(i,:)',:)'));
   if ac>fitacc, fitacc=ac;end;
end;
 
%  Build up type 0 representation:
 
if d>1,
   P2=[0 nh fitacc zeros(1,d-2);H;V -ones(nv,1)];
else
   P2=[0 fitacc;H;V [-1; -1]];
end;
 
%  Give warning message if error level exceeds global error bound DELTA:
 
if fitacc>DELTA, warndel;end;
 
%  Give warning message if vertex falls outside KAPPA hypercube:
 
if max(max(abs(V)))>KAPPA, warnkap;end;
return;
      
