function vol=mcvol(E,n);
%  MCVOL: estimate the volume of the intersection of ellipsoids
%  Inputs:
%    E[[1 0;1 0]]  =  array of ellipsoids
%    n[1]          =  number of grid points in each dimension
%    vol           =  volume of ellipsoid
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%   Find the dimension of the space:
 
[mr,mc]=size(E);d=mc-1;
 
%   Find the number of ellipsoids:
 
noell=round(mr/mc);
 
%   Compute the ranges of ellipsoids
 
lowr=[];highr=[];
for i=1:noell,
   [a,b]=ellrange(E((i-1)*mc+1:i*mc,:));
   lowr=[lowr;a];highr=[highr; b];
end;
lo=max(lowr);
hi=min(highr);
 
%  Enclose all the ellipsoids in a smallest axes aligned boc:
 
B=defbox(lo,hi);totvol=polvol(B);
 
%  Generate grid-point index-vectors in array `var':
 
var=(1:n)';
for i=2:d,
   nr=size(var,1);
   v=[ones(nr,1) var ];  
   for j=2:n, v=[v;ones(nr,1)*j var];end;
   var=v;
end;
 
%  Compute grid points and testing whether they are in all ellipsoids:
 
var=var/n; nr=size(var,1);del=hi-lo;
count=0;  % = counter of points found inside ellipsoids
for i=1:nr,
   x=lo+var(i,:).*del; bo=1>0;j=1;
   while bo & j<noell,
      bo=inell(x,E((j-1)*mc+1:j*mc,:));
      j=j+1;
   end;
   if bo, count=count+1;end;
end;
 
%  Estimate the volume by the proportion of grid ppoints found
%  inside all ellipsoids:
 
vol=count/nr;
return;
 
   
   
