function [c,r]=polcent(P,typ,p);
%  POLCENT: compute the centre of a polytope
%  Inputs:
%    P[[1 eps;1 0]] = polytope
%     typ['cheb'] =  'mass' or 'cheb'
%        p   = order of norm  p >= 1
%  Outputs:
%     c[0]   =   centre of  polytope
%     r[0]   =   radius of the polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
%  
 
 
 
[er,ec]=size(P);
 
%  Treatment of 1D case:
 
if (ec==2),
  c=(P(2,2)-P(3,2))/2; r=(P(2,2)+P(3,2))/2;
  return;
end;  
 
%  Default settings:
 
if (nargin<2), typ='cheb';end;
if (nargin<3), p=2;end;
options=[1e-4,150]; % = default for optimisation
 
%  Find vertices:
 
[V,nv]=vertices(P);
 
%  Compute two types of centres:
 
  if (strcmp(typ,'mass')),
    c=mean(V);h=V-ones(nv,1)*c; % mass centre
    r=sqrt(max(diag(h*h')));    % radius for mass centre	
 else
    [c,r]=lpcent(V,p,options);  % Chebyshev centre 
  end;
  return;
 
 
 
