function pt=projpont(p,G);
%   PROJPONT: project point onto polytope
%   Inputs:
%     p[1]  =  points
%     G[[1 eps;1 0]]   = polytope
%   Outputs:
%     pt[0]    =  projected point
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
%  The default values are set:
 
if nargin<1, V=[0];end;acc=eps;H=[1 eps;1 0];
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Giving warning if KAPPA-hypercube is violated:
 
if max(abs(p))>KAPPA, warnkap;end;
 
%  Finding dimensions:
 
[rG,cG]=size(G);[rp,cp]=size(p);if cp>1, p=p';rp=cp;cp=1;end;
if rG==0|cG==0, pt=[];end;
if cG>2, d=cG-1;end;
[rp,cp]=size(p);
if (rp<d),
   disp('Dimension of object and point is different in PROJPONT');
break;end;
 
%  Dealing with the 1D case:
 
if cG==2, % the one dimensional case
  if (G(2,2)<p(1)), pt=G(2,2);elseif(p(1)<-G(2,3)), pt=-G(3,2);else pt=p;end;
end;
 
%  Finding the visible facets:
 
[F,nf]=faces(G);    % extraction of relevant hyperplanes/facets
vis=F*[-p;1]<DELTA;
nvis=sum(vis);fac=F(vis,:);
f1=fac(:,1:d);b=fac(:,d+1);c=nvis;
comtot=c;
for i=2:d, c=c*(nvis-i+1)/i;comtot=comtot+c;end;
 
%  Initialisation of array of projected points onto visible faces:
 
pts=zeros(comtot,d);
 
%  Pre-computation of combinations of facets to form faces
%  onto which projection is to be done:
 
j=0;
for i=1:d,
  [C,ncom]=combin(nvis,i);
  for i=1:ncom,
    j=j+1;
    L=fac(C(i,:)',1:d);b=fac(C(i,:)',d+1);
    pts(j,:)=(p+L'*pinv(L*L')*(b-L*p))';
  end;
end;
 
%  Finding the nearest projected point:
 
pind=1;
if ~isempty(pts),
   pptsmin=norm(p'-pts(pind,:));
   for i=1:comtot,   % selecting the nearest suitable point
     if min(fac*[-pts(i,:)';1])>-DELTA,
      ppts=norm(p'-pts(i,:));
       if ppts<pptsmin,
         pptsmin=ppts;pind=i;
       end;
     end;
   end;
else
   pt=p;
   return;
end;
 
%  Setting the value of the nearest projected point:
 
pt=pts(pind,:)';
return;
