function D=subtract(A,B);
%  SUBTRACT: compute the Minkowski difference of two polytopes
%   Inputs:
%     A[[1 eps;1 0]] = first polytope
%     B[[1 eps;1 0]] = second polytope
%   Outputs:
%     D[[1 eps;1 0]] = difference polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
%  The difference set is defined by
%  $$          D = \{ x | x+B \subseteq A \} $$
%  where
%   $ A,\ B$  are two polytopes for which the difference is sought
%     $D$   is the difference polytope.
 
%  Set the global precision bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  List the vertices of both polytopes:
 
[V,n]=vertices(B);[Va,na]=vertices(A);
 
%  Enclose the difference into a conservative box to imrove accuacy
%  of computations:
 
Box=defbox(min(Va)-max(V),max(Va)-min(V));
 
%  Find dimension and listing facet inequalities of A :
 
d=size(V,2);[F,m]=faces(A);
 
%  Compute the inequality constraints of the Minkowski difference:
 
a=F(:,d+1)-max(V*F(:,1:d)')'; 
F=[F(:,1:d) a ];
 
%  Compute the intersection set to obtain the difference:
   
D=dconvh(F,'inter',0,Box);
return
