function axout=view2d(P,a,c,axin);
%  VIEW2D: display 2D wireframe projections of a polytope on pairs of axes
%  Inputs:
%   P[[1 eps;1 0]] = polytope
%   a[[1 2]] = indices of axis of interest
%    c['b']  = colour of wireframe plot
%     axin[gca]   = vector of axes handles to be used
%  Outputs:
%     axout  = vector of axes handles produced
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  Carry out diagnostics:
 
if isempty(P),
   disp('Warning: polytope was empty in VIEW2D');return;
end;
[n,dn]=size(P);d=dn-1;
if d<2, 
   disp('Error:dimension of polytope must be at least 2 in VIEW2D');return;
end;
 
%  Define defaults:
 
if nargin<2, a=[1 2];end;na=length(a);
if nargin<3, c='red'; clf; end;
 
%  List vertices and dimensions is produced:
 
[V,nv]=vertices(P);
nh=P(1,2);
n1=1+nh+2*nv+1;n2=n1+nv-1;
 
%   Compute the vertex-vertex and vertex-facet adjacency tables:
 
VV=vvf(P);
[nv,cvv]=size(VV);
 
%   Produce the projected wireframe view for a pair of axis only :
 
if na==2, 
   if nargin<4, 
      axout=newplot;
      title(['Projection to ' num2str(a(1)) '-' num2str(a(2)) ' axes']);
   else
      axes(axin);             
   end;
   
   for k=1:nv,
   d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(1)) V(VV(k,j),a(1))],[V(k,a(2)) V(VV(k,j),a(2))]);    
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   if nargin>3, axout=axin;end;
end;
 
%  Produce the projected wireframe view for 3 axes pairs:
 
if na==3, 
   axout=[];   
   if nargin<4, 
     subplot(221),np1=newplot;
     title(['Projection to ' num2str(a(1)) '-' num2str(a(2)) ' axes']);
   else 
     axes(axin(1));   
   end;
   
   for k=1:nv,
      d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(1));V(VV(k,j),a(1))],[V(k,a(2));V(VV(k,j),a(2))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
 
   if nargin<4, 
     subplot(222),np2=newplot;
     title(['Projection to ' num2str(a(1)) '-' num2str(a(3)) ' axes']);
   else 
     axes(axin(2));   
   end;
   
   for k=1:nv,
       d1=VV(k,:)>0 ;cvv=sum(d1);
       for j=1:cvv,
         l=line([V(k,a(1));V(VV(k,j),a(1))],[V(k,a(3));V(VV(k,j),a(3))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   
   if nargin<4, 
      subplot(223),np3=newplot;  
      title(['Projection to ' num2str(a(2)) '-' num2str(a(3)) ' axes']);
   else 
      axes(axin(3)); 
   end;
   
   for k=1:nv,
      d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(2));V(VV(k,j),a(2))],[V(k,a(3));V(VV(k,j),a(3))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   if nargin>3, axout=axin;else axout=[np1 np2 np3];end;   
  
end;
 
%  Produce the projected wireframe view for 4 axes, i.e. 6 axes
%  pairs in all combinations:
 
if na==4,
      
   if nargin<4,
      subplot(321),np1=newplot;
      title(['Projection to ' num2str(a(1)) '-' num2str(a(2)) ' axes']);
   else
      axes(axin(1));
   end;
   for k=1:nv,
      d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(1));V(VV(k,j),a(1))],[V(k,a(2));V(VV(k,j),a(2))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
 
   if nargin<4,  subplot(322),np2=newplot;
      title(['Projection to ' num2str(a(1)) '-' num2str(a(3)) ' axes']);
   else
      axes(axin(2));
   end;
   for k=1:nv,
       d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(1));V(VV(k,j),a(1))],[V(k,a(3));V(VV(k,j),a(3))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   
   if nargin<4,  subplot(323),np3=newplot;
      title(['Projection to ' num2str(a(1)) '-' num2str(a(4)) ' axes']);
   else
      axes(axin(3));
   end;
   for k=1:nv,
      d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(1));V(VV(k,j),a(1))],[V(k,a(4));V(VV(k,j),a(4))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
 
   if nargin<4,  subplot(324), np4=newplot;
      title(['Projection to ' num2str(a(2)) '-' num2str(a(3)) ' axes']);
  else
      axes(axin(4));
   end;
   
   for k=1:nv,
         d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(2));V(VV(k,j),a(2))],[V(k,a(3));V(VV(k,j),a(3))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
 
   if nargin<4,  subplot(325),np5=newplot;
      title(['Projection to ' num2str(a(2)) '-' num2str(a(4)) ' axes']);
    else
      axes(axin(5));
   end;
   
   for k=1:nv,
       d1=VV(k,:)>0 ;cvv=sum(d1);
       for j=1:cvv,
         l=line([V(k,a(2));V(VV(k,j),a(2))],[V(k,a(4));V(VV(k,j),a(4))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   
   if nargin<4,  subplot(326),np6=newplot;
      title(['Projection to ' num2str(a(3)) '-' num2str(a(4)) ' axes']);
  else
      axes(axin(6));
   end;
   
   for k=1:nv,
      d1=VV(k,:)>0 ;cvv=sum(d1);
      for j=1:cvv,
         l=line([V(k,a(3));V(VV(k,j),a(3))],[V(k,a(4));V(VV(k,j),a(4))]);
         set(l,'Color',c(1)); 
		 if length(c)>1, if c(2)==':',set(l,'linestyle',':');end;end;
      end;
   end;
   
   if nargin>3, 
      axout=axin;
   else 
      axout=[np1 np2 np3 np4 np5 np6];
   end;
   
end;
 
return;
   
   
