function [v,fitacc]=vtxfit(H);
%  VTXFIT: fit a point to d hyperplanes
%  Inputs:
%    H   =   list of linear equalities
%  Outputs:
%    v   =   the point fitted
%   fitacc  =  fitting accuracy of the point
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
%  Find dimensions:
 
[nh,d]=size(H);d=d-1;
 
%  Form the LHS(H1), RHS(H2) of the equation:
 
H1=H(:,1:d);H2=H(:,d+1);
 
%  Compute the singular value decomposition:
 
[U,S,V]=svd(H1);
 
%  Form new RHS b :
 
b=U'*H2;
 
%  Solve the simple equations by analyis of cases:
 
s=diag(S);ls=length(s);z=zeros(ls,1);
for i=1:ls,
   if abs(s(i))>eps, z(i)=b(i)/s(i); 
   else z(i)=0;end;
end;
 
%  Get back the final solution:
 
v=(V*z)';
 
%  Compute fitting accuracy :
 
fitacc=max(abs(H1*v'-H2));
return;
