# File    : TARGET.tmf
#
# $Revision 1.1 $
#
# Abstract:
#       Real-Time Workshop template makefile for building a Neutrino-based 
#       stand-alone real-time version of SIMULINK model using 
#       generated C code.
#
#       Note that this template is automatically customized by the Real-Time
#       Workshop build procedure to create "<model>.mk"
#
#       The following defines can be used to modify the behavior of the
#       build:
#         OPTS           - User specific compile options, such as 
#                          OPTS=-DMULTITASKING to enable multitasking mode.
#         OPT_OPTS       - Optimization options. Default is -Oatx. To enable
#                          debugging define DEBUG.
#         USER_SRCS      - Additional user sources, such as files needed by
#                          S-functions.
#         USER_INCS  - Additional include paths 
#                          (i.e. USER_INCS="-Iwhere-ever -Iwhere-ever2")


#------------------------ Macros read by make_rtw -----------------------------
#
# The following macros are read by the Real-Time Workshop build procedure:
#
#  MAKE            - This is the command used to invoke the make utility
#  HOST            - What platform this template makefile is targeted for 
#                    (i.e. PC or UNIX)
#  BUILD           - Invoke make from the Real-Time Workshop build procedure 
#                    (yes/no)?
#  SYS_TARGET_FILE - Name of system target file.

MAKE            = make
HOST            = PC
BUILD           = no
SYS_TARGET_FILE = rtlab.tlc

#---------------------- Tokens expanded by make_rtw ---------------------------
#
# The following tokens, when wrapped with "|>" and "|<" are expanded by the 
# Real-Time Workshop build procedure.
#   
#  MODEL_NAME    - Name of the SIMULINK block diagram
#  MODEL_MODULES - Any additional generated source modules
#  MAKEFILE_NAME - Name of makefile created from template makefile <model>.mk
#  MATLAB_ROOT   - Path to were MATLAB is installed. 
#  S_FUNCTIONS   - List of S-functions.
#  SOLVER        - Solver source file name
#  NUMST         - Number of sample times
#  TID01EQ       - yes (1) or no (0): Are sampling rates of continuous task 
#                  (tid=0) and 1st discrete task equal.
#  NCSTATES      - Number of continuous states
#  COMPUTER      - Computer type. See the MATLAB computer command.
#  BUILDARGS     - Options passed in at the command line.

MODEL           = rigallocmpcna1_1_sm_master
MODULES         = rigallocmpcna1_1_sm_master_data.c 
MAKEFILE        = rigallocmpcna1_1_sm_master.mk
MATLAB_ROOT     = C:\MATLAB71
ALT_MATLAB_ROOT = C:\MATLAB71
S_FUNCTIONS     =  sfun_motor.c sfun_dm6210_ain.c RECV_Param.c OP_SEND.c sfun_stepmotor.c
SOLVER          = 
NUMST           = 1
TID01EQ         = 0
NCSTATES        = 0
COMPUTER        = PCWIN
BUILDARGS       =  ADD_MDL_NAME_TO_GLOBALS=1 EXTMODE_STATIC_ALLOC_SIZE=1000000 MODELLIB=rigallocmpcna1_1_sm_masterlib.lib SHARED_SRC= SHARED_SRC_DIR= SHARED_BIN_DIR= MODELREF_LINK_LIBS= SHARED_LIB= RELATIVE_PATH_TO_ANCHOR=.. MODELREF_TARGET_TYPE=NONE
MULTITASKING    = 0


#----------------------------- Source Files ------------------------------
REQ_SRCS  = $(MODEL).c $(MODULES) model_main.c rt_sim.c rtwlog.c rt_nonfinite.c $(SOLVER) $(EXT_SRC)

# Remove Opal-RT block sources from the list of S-Functions: they are provided with RT-LAB
# Leave any other S-Functions.
SFS_TMP1 = $(S_FUNCTIONS:recv_param.c=)
SFS_TMP1a = $(SFS_TMP1:RECV_Param.c=)
SFS_TMP2 = $(SFS_TMP1a:recv_rt.c=)
SFS_TMP3 = $(SFS_TMP2:op_send.c=)
SFS_TMP3a = $(SFS_TMP3:OP_SEND.c=)
SFS_TMP4 = $(SFS_TMP3a:send_rt.c=)
SFS_TMP5 = $(SFS_TMP4:sfun_ip320_analog_in.c=)
SFS_TMP6 = $(SFS_TMP5:sfun_ip220aout.c=)
SFS_TMP7 = $(SFS_TMP6:sfun_ip470_digital_in.c=)
SFS_TMP8 = $(SFS_TMP7:sfun_ip470_digital_out.c=)
SFS_TMP9 = $(SFS_TMP8:sfun_ip_quad.c=)
SFS_TMP10 = $(SFS_TMP9:sfun_timing.c=)
SFS_TMP11 = $(SFS_TMP10:optrigger.c=)
SFS_TMP12 = $(SFS_TMP11:sfun_mq3_analog_out.c=)
SFS_TMP13 = $(SFS_TMP12:sfun_mq3_digital_out.c=)
SFS_TMP14 = $(SFS_TMP13:sfun_mq3_analog_in.c=)
SFS_TMP15 = $(SFS_TMP14:sfun_mq3_digital_in.c=)
SFS_TMP16 = $(SFS_TMP15:sfun_mq3_quad.c=)
SFS_TMP17 = $(SFS_TMP16:sfun_sync_mq3.c=)
SFS_TMP18 = $(SFS_TMP17:sfun_sync_acl.c=)
SFS_TMP19 = $(SFS_TMP18:opsnapshot.c=)
SFS_TMP20 = $(SFS_TMP19:opwritefile.c=)
SFS_TMP21 = $(SFS_TMP20:send_fw.c=)
SFS_TMP22 = $(SFS_TMP21:recv_fw.c=)
SFS_TMP23 = $(SFS_TMP22:simulation_info.c=)
SFS_TMP24 = $(SFS_TMP23:sfun_ip_encoder6.c=)
SFS_TMP25 = $(SFS_TMP24:usr_delay.c=)
SFS_TMP26 = $(SFS_TMP25:simulation_events2.c=)
SFS_TMP27 = $(SFS_TMP26:sfun_ipunidigio24iodout.c=)
SFS_TMP28 = $(SFS_TMP27:sfun_ipunidigio24iodin.c=)
SFS_TMP29 = $(SFS_TMP28:sfun_ipad16ssain.c=)
SFS_TMP30 = $(SFS_TMP29:sfun_s626_aout.c=)
SFS_TMP31 = $(SFS_TMP30:sfun_s626ain.c=)
SFS_TMP32 = $(SFS_TMP31:sfun_s626_enc.c=)
SFS_TMP33 = $(SFS_TMP32:sfun_s626_dout.c=)
SFS_TMP34 = $(SFS_TMP33:sfun_s626_din.c=)
SFS_TMP35 = $(SFS_TMP34:sfun_dm6210_dout.c=)
SFS_TMP36 = $(SFS_TMP35:sfun_dm6210_din.c=)
SFS_TMP37 = $(SFS_TMP36:sfun_dm6210_ain.c=)
SFS_TMP38 = $(SFS_TMP37:sfun_dm6816_pwm.c=)
SFS_TMP39 = $(SFS_TMP38:sfun_spawn_proc.c=)
SFS_TMP40 = $(SFS_TMP39:sfun_dm6804_pwm_in.c=)
SFS_TMP41 = $(SFS_TMP40:sfun_dm6804_frequ_in.c=)
SFS_TMP42 = $(SFS_TMP41:sfun_dcc10p_pwm_in.c=)
SFS_TMP43 = $(SFS_TMP42:sfun_canac2_ctl.c=)
SFS_TMP44 = $(SFS_TMP43:sfun_send_canac2.c=)
SFS_TMP45 = $(SFS_TMP44:sfun_canac2_recv.c=)
SFS_TMP46 = $(SFS_TMP45:sync_vme.c=)
SFS_TMP47 = $(SFS_TMP46:sfun_sync_dcc10p.c=)
SFS_TMP48 = $(SFS_TMP47:sfun_ip330_ain.c=)
SFS_TMP49 = $(SFS_TMP48:sfun_ip230_aout.c=)
SFS_TMP50 = $(SFS_TMP49:sfun_ip501_16_ctrl.c=)
SFS_TMP51 = $(SFS_TMP50:sfun_send_async.c=)
SFS_TMP52 = $(SFS_TMP51:sfun_recv_async.c=)
SFS_TMP53 = $(SFS_TMP52:sfun_gen_async_ctrl.c=)
SFS_TMP54 = $(SFS_TMP53:sfun_ip500_ctrl.c=)
SFS_TMP55 = $(SFS_TMP54:sfun_ip341_ain.c=)
SFS_TMP56 = $(SFS_TMP55:sfun_opfromfile.c=)
SFS_TMP57 = $(SFS_TMP56:sfun_dm6420_ain.c=)
SFS_TMP58 = $(SFS_TMP57:sfun_dm6420_aout.c=)
SFS_TMP59 = $(SFS_TMP58:sfun_dm6420_din.c=)
SFS_TMP60 = $(SFS_TMP59:sfun_dm6420_dout.c=)
SFS_TMP61 = $(SFS_TMP60:sfun_dcc10p_freq_in.c=)
SFS_TMP62 = $(SFS_TMP61:sfun_dcc10p_pwm_out.c=)
SFS_TMP63 = $(SFS_TMP62:sfun_dcc10p_event_detector.c=)
SFS_TMP64 = $(SFS_TMP63:sfun_dcc10p_event_generator.c=)
SFS_TMP78 = $(SFS_TMP64:sfun_opexternvar.c=)
SFS_TMP79 = $(SFS_TMP78:sfun_time_factor.c=)
SFS_TMP80 = $(SFS_TMP79:sfun_ohci_info.c=)
SFS_TMP83 = $(SFS_TMP80:sfun_dm6814_enc.c=)
SFS_TMP84 = $(SFS_TMP83:simulation_events.c=)
SFS_TMP85 = $(SFS_TMP84:sfun_ni6602_pwm_out.c=)
SFS_TMP86 = $(SFS_TMP85:sfun_ni6602_pwm_in.c=)
SFS_TMP87 = $(SFS_TMP86:sfun_s626_sync.c=)
SFS_TMP88 = $(SFS_TMP87:sfun_sync_vme200_2.c=)
SFS_TMP89 = $(SFS_TMP88:sfun_share_mem_ctrl.c=)
SFS_TMP90 = $(SFS_TMP89:sfun_share_mem_read.c=)
SFS_TMP91 = $(SFS_TMP90:sfun_share_mem_write.c=)
SFS_TMP92 = $(SFS_TMP91:read_dinamo.c=)
SFS_TMP93 = $(SFS_TMP92:sfun_subsystem_trigger.c=)
SFS_TMP94 = $(SFS_TMP93:sfun_serial_ctrl.c=)
SFS_TMP96 = $(SFS_TMP94:sfun_ni60xe_ain.c=)
SFS_TMP97 = $(SFS_TMP96:sfun_ni60xe_aout.c=)
SFS_TMP98 = $(SFS_TMP97:sfun_ni60xe_din.c=)
SFS_TMP99 = $(SFS_TMP98:sfun_ni60xe_dout.c=)
SFS_TMP100 = $(SFS_TMP99:sfun_ni6602_freq_in.c=)
SFS_TMP101 = $(SFS_TMP100:sfun_ni670x_aout.c=)
SFS_TMP102 = $(SFS_TMP101:sfun_ni670x_din.c=)
SFS_TMP103 = $(SFS_TMP102:sfun_ni670x_dout.c=)
SFS_TMP104 = $(SFS_TMP103:sfun_ni671x_aout.c=)
SFS_TMP105 = $(SFS_TMP104:sfun_ni671x_dout.c=)
SFS_TMP106 = $(SFS_TMP105:sfun_ni671x_din.c=)
SFS_TMP107 = $(SFS_TMP106:sfun_ni671x_pwm_in.c=)
SFS_TMP108 = $(SFS_TMP107:sfun_ni60xe_io_trigger.c=)
SFS_TMP109 = $(SFS_TMP108:sfun_ni671x_pwm_out.c=)
SFS_TMP110 = $(SFS_TMP109:sfun_async_st_emit.c=)
SFS_TMP111 = $(SFS_TMP110:sfun_ni660x_din.c=)
SFS_TMP112 = $(SFS_TMP111:sfun_ni660x_dout.c=)
SFS_TMP113 = $(SFS_TMP112:sfun_dcc10p_counter.c=)
SFS_TMP114 = $(SFS_TMP113:sfun_ni660x_sync.c=)
SFS_TMP115 = $(SFS_TMP114:sfun_dm6604_aout.c=)
SFS_TMP116 = $(SFS_TMP115:sfun_generic_8255_din.c=)
SFS_TMP117 = $(SFS_TMP116:sfun_generic_8255_dout.c=)
SFS_TMP118 = $(SFS_TMP117:sfun_dm6420_sync.c=)
SFS_TMP119 = $(SFS_TMP118:sfun_ni6602_event_detector.c=)
SFS_TMP120 = $(SFS_TMP119:sfun_dcc10p_counter.c=)
SFS_TMP121 = $(SFS_TMP120:sfun_ip408_dout.c=)
SFS_TMP122 = $(SFS_TMP121:sfun_ip408_din.c=)
SFS_TMP123 = $(SFS_TMP122:sfun_ni6602_event_generator.c=)
SFS_TMP124 = $(SFS_TMP123:sfun_data_conv.c=)
SFS_TMP125 = $(SFS_TMP124:sfun_ni671x_sync.c=)
SFS_TMP126 = $(SFS_TMP125:sfun_dcc10p_pulse_gen.c=)
SFS_TMP127 = $(SFS_TMP126:recv_ohci.c=)
SFS_TMP128 = $(SFS_TMP127:send_ohci.c=)
SFS_TMP129 = $(SFS_TMP128:error_status.c=)
SFS_TMP130 = $(SFS_TMP129:fake_io.c=)
SFS_TMP131 = $(SFS_TMP130:op_getpid.c=)
SFS_TMP132 = $(SFS_TMP131:print_msg.c=)
SFS_TMP133 = $(SFS_TMP132:read_pport.c=)
SFS_TMP134 = $(SFS_TMP133:run_model.c=)
SFS_TMP135 = $(SFS_TMP134:sfun_take_time.c=)
SFS_TMP136 = $(SFS_TMP135:sfun_pcdio96_din.c=)
SFS_TMP137 = $(SFS_TMP136:sfun_pcdio96_dout.c=)
SFS_TMP138 = $(SFS_TMP137:opassertion.c=)
SFS_TMP139 = $(SFS_TMP138:checkoutputwidth.c=)
SFS_TMP140 = $(SFS_TMP139:signalcompression.c=)
SFS_TMP141 = $(SFS_TMP140:signaluncompression.c=)
SFS_TMP142 = $(SFS_TMP141:sfun_ophsdio64_event_generator.c=)
SFS_TMP143 = $(SFS_TMP142:sfun_ophsdio64_event_detector.c=)
SFS_TMP144 = $(SFS_TMP143:sfun_ophsdio64_apwm_out.c=)
SFS_TMP145 = $(SFS_TMP144:sfun_ophsdio64_quad_generator.c=)
SFS_TMP146 = $(SFS_TMP145:sfun_ophsdio64_sync.c=)
SFS_TMP147 = $(SFS_TMP146:sfun_ophsdio64_engine_ctrl.c=)
SFS_TMP148 = $(SFS_TMP147:sfun_op_engine_pulse.c=)
SFS_TMP149 = $(SFS_TMP148:sfun_ip440_din.c=)
SFS_TMP150 = $(SFS_TMP149:sfun_ip445_dout.c=)
SFS_TMP151 = $(SFS_TMP150:sfun_ip480_ct.c=)

SFS_TMP173 = $(SFS_TMP151:sfun_ctrl_bm.c=)
SFS_TMP174 = $(SFS_TMP173:sfun_ctrl_rpgm.c=)
SFS_TMP175 = $(SFS_TMP174:sfun_ctrl_sm.c=)
SFS_TMP176 = $(SFS_TMP175:sfun_ctrl_stat_reg.c=)
SFS_TMP177 = $(SFS_TMP176:sfun_fctdigitalin.c=)
SFS_TMP178 = $(SFS_TMP177:sfun_fctdigitalswitch.c=)
SFS_TMP179 = $(SFS_TMP178:sfun_fctespg.c=)
SFS_TMP180 = $(SFS_TMP179:sfun_fctmultieventcapt.c=)
SFS_TMP181 = $(SFS_TMP180:sfun_fctmultieventgen.c=)
SFS_TMP182 = $(SFS_TMP181:pause_model.c=)
SFS_TMP183 = $(SFS_TMP182:opmonitor.c=)
SFS_TMP184 = $(SFS_TMP183:sfun_q8_da.c=)
SFS_TMP185 = $(SFS_TMP184:sfun_q8_da.c=)
SFS_TMP186 = $(SFS_TMP185:sfun_q8_do.c=)
SFS_TMP187 = $(SFS_TMP186:sfun_q8_di.c=)
SFS_TMP188 = $(SFS_TMP187:sfun_q8_co.c=)
SFS_TMP189 = $(SFS_TMP188:sfun_q8_wd.c=)
SFS_TMP190 = $(SFS_TMP189:sfun_q8_pwm.c=)
SFS_TMP191 = $(SFS_TMP190:sfun_q8_cfgcntr.c=)
SFS_TMP192 = $(SFS_TMP191:sfun_q8_cfgencio.c=)
SFS_TMP193 = $(SFS_TMP192:sfun_q8_en.c=)
SFS_TMP194 = $(SFS_TMP193:sfun_q8_stat.c=)
SFS_TMP195 = $(SFS_TMP194:sfun_q8_cfgext.c=)
SFS_TMP196 = $(SFS_TMP195:sfun_q8_tb.c=)
SFS_TMP197 = $(SFS_TMP196:sfun_q8_exttb.c=)
SFS_TMP198 = $(SFS_TMP197:sfun_q8_adtb.c=)
SFS_TMP199 = $(SFS_TMP198:sfun_q8_adexttb.c=)
SFS_TMP200 = $(SFS_TMP199:sfun_q8_comp.c=)
SFS_TMP201 = $(SFS_TMP200:sfun_q8_enr.c=)
SFS_TMP202 = $(SFS_TMP201:sfun_q8_encflags.c=)
SFS_TMP203 = $(SFS_TMP202:sfun_q8_period.c=)

SFS_TMP207 = $(SFS_TMP203:sfun_nexus_tap.c=)
SFS_TMP208 = $(SFS_TMP207:sfun_nexus_replace.c=)
SFS_TMP209 = $(SFS_TMP208:sfun_nexus_sync.c=)
SFS_TMP210 = $(SFS_TMP209:sfun_nexus_pci_controller.c=)
SFS_TMP211 = $(SFS_TMP210:sfun_nexus_trig_mgr.c=)
SFS_TMP212 = $(SFS_TMP211:sfun_nexus_sub_timer.c=)
SFS_TMP213 = $(SFS_TMP212:sfun_opmstack_ctrl.c=)
SFS_TMP214 = $(SFS_TMP213:sfun_opconfig_port.c=)
SFS_TMP215 = $(SFS_TMP214:mstack_ccp_cal.c=)
SFS_TMP216 = $(SFS_TMP215:mstack_ccp_in.c=)
SFS_TMP217 = $(SFS_TMP216:mstack_analog_in.c=)
SFS_TMP218 = $(SFS_TMP217:mstack_digital_in.c=)
SFS_TMP219 = $(SFS_TMP218:mstack_ccp_ctl.c=)

SFS_TMP221 = $(SFS_TMP219:sfun_ctrl_pdlm.c=)
SFS_TMP222 = $(SFS_TMP221:sfun_fctdigitalout.c=)

SFS_TMP228 = $(SFS_TMP222:sfun_openginepsm.c=)
SFS_TMP229 = $(SFS_TMP228:pycall.c=)

SFS_TMP231 = $(SFS_TMP229:sfun_ophsdio64_din.c=)
SFS_TMP232 = $(SFS_TMP231:sfun_ophsdio64_dout.c=)
SFS_TMP233 = $(SFS_TMP232:sfun_ophsdio64_analog_out.c=)
SFS_TMP234 = $(SFS_TMP233:sfun_ctrl_op5130.c=)
SFS_TMP235 = $(SFS_TMP234:sfun_fctanalogout.c=)
SFS_TMP236 = $(SFS_TMP235:sfun_ctrl_stat_reg.c=)
SFS_TMP237 = $(SFS_TMP236:sfun_ip235_aout.c=)
SFS_TMP238 = $(SFS_TMP237:sfun_opdataset.c=)
SFS_TMP239 = $(SFS_TMP238:sfun_opinterpol.c=)
SFS_TMP240 = $(SFS_TMP239:nrt.c=)
SFS_TMP241 = $(SFS_TMP240:opplotfile.c=)
SFS_TMP242 = $(SFS_TMP241:pubhlaclassattr.c=)
SFS_TMP243 = $(SFS_TMP242:subhlaclassattr.c=)
SFS_TMP244 = $(SFS_TMP243:pubhlainteraction.c=)
SFS_TMP245 = $(SFS_TMP244:subhlainteraction.c=)
SFS_TMP246 = $(SFS_TMP245:pubentitytype.c=)
SFS_TMP247 = $(SFS_TMP246:hlafedoptions.c=)
SFS_TMP248 = $(SFS_TMP247:sfun_ctrl_asm.c=)
SFS_TMP249 = $(SFS_TMP248:sfun_ctrl_pom.c=)
SFS_TMP250 = $(SFS_TMP249:sfun_ctrl_rsm.c=)
SFS_TMP251 = $(SFS_TMP250:sfun_fctresistivesensor.c=)
SFS_TMP252 = $(SFS_TMP251:sfun_fctdigitaloutgated.c=)
SFS_TMP253 = $(SFS_TMP252:opendianswapper.c=)
SFS_TMP254 = $(SFS_TMP253:sfun_ni60xe_pwm_in.c=)
SFS_TMP255 = $(SFS_TMP254:sfun_ophsdio64_analog_in.c=)
SFS_TMP256 = $(SFS_TMP255:sfun_fctanalogin.c=)
SFS_TMP257 = $(SFS_TMP256:sfun_lapcan_media.c=)
SFS_TMP258 = $(SFS_TMP257:sfun_ni60xe_freq_in.c=)
SFS_TMP259 = $(SFS_TMP258:sfun_ni60xe_pwm_out.c=)

SFS_TMP260 = $(SFS_TMP259:sfun_xplane.c=)
SFS_TMP261 = $(SFS_TMP260:sfun_opjoystick.c=)

SFS_TMP262 = $(SFS_TMP261:fts2abcd.c=)
SFS_TMP263 = $(SFS_TMP262:fts2flux.c=)
SFS_TMP264 = $(SFS_TMP263:fts2dla.c=)
SFS_TMP265 = $(SFS_TMP264:fts2hfun.c=)
SFS_TMP266 = $(SFS_TMP265:fts2abcd_dtc.c=)

S_FUNC_SRCS = $(SFS_TMP266:optaketime.c=)

#############################################################################
#
#    For CarSim/VehSim/TruckSim by Mechanical SImulation Corp.
#
#    The product name: MSC_PRODUCT_ID         carsim, vehsim, trucksim
#    The product type: MSC_PRODUCT_TYPE       i_i, i_s__ss, s_ss ...
#    Version Number:   MSC_PRODUCT_VERSION    5.25, 6.02, 3.04 ...
#
#############################################################################
ifeq "$(MSC_PRODUCT_TYPE)" ""
# 	Do nothing here
else
  include /usr/$(MSC_PRODUCT_ID)/$(MSC_PRODUCT_VERSION)/$(MSC_PRODUCT_ID).opt
endif
#
#############################################################################
#                 End CarSim/TruckSim/VehSim
#############################################################################

SRCS1 = $(REQ_SRCS)  $(INTERNAL_ADD_SOURCE_FILE)  $(S_FUNC_SRCS) $(USER_SRCS) 
SRCS  = $(filter-out $(INTERNAL_IGN_SOURCE_FILE), $(SRCS1))

UNAME = $(shell uname)
ifeq "$(UNAME)" "QNX"		##### nto
	include qnxnto.opt
else
	ifeq "$(UNAME)" "Linux"	##### Linux (RedHawk)
		include redhawk.opt
	else
		include win32.opt
	endif
endif

#------------------------------ Include Path -----------------------------

MATLAB_INCLUDES = \
	-I$(TARGET_MATLAB_ROOT)/simulink/include \
	-I$(TARGET_MATLAB_ROOT)/extern/include \
	-I$(TARGET_MATLAB_ROOT)/rtw/c/src \
	-I$(TARGET_MATLAB_ROOT)/rtw/c/libsrc

RTLAB_INCLUDES = \
	-I$(TARGET_RTLAB_ROOT)/common/include \
	-I$(TARGET_RTLAB_ROOT)/common/include_target \
	-I$(TARGET_RTLAB_ROOT)/RT-LAB/include

INCLUDES = -I. $(MATLAB_INCLUDES) $(RTLAB_INCLUDES) $(INTERNAL_INCLUDE_PATH) $(USER_INCS)

#-------------------------------- C Flags --------------------------------
# General User Options
ifeq ($(OP_MATLABR12),1)
MATLABVERSION_CFLAGS = -DOP_MATLABR12
endif
ifeq ($(OP_MATLABR13),1)
MATLABVERSION_CFLAGS = -DOP_MATLABR13
endif
ifeq ($(OP_MATLABR14),1)
MATLABVERSION_CFLAGS = -DOP_MATLABR14
endif

OPTS =

ANSI_OPTS =

CC_OPTS = -c  $(OPT_OPTS) $(OPTS) $(ANSI_OPTS) $(EXT_CC_OPTS)

CPP_REQ_DEFINES = -DMODEL=$(MODEL) -DRT -DNUMST=$(NUMST) \
                  -DTID01EQ=$(TID01EQ) -DNCSTATES=$(NCSTATES) \
                  -DMULTITASKING=$(MULTITASKING) -D_SIMULINK -DRTLAB $(MATLABVERSION_CFLAGS)	

CFLAGS = $(CC_OPTS) $(CPP_REQ_DEFINES) $(TARGET_CFLAGS) $(INCLUDES)

#------------------------------- LD Flags --------------------------------
LDFLAGS = $(LD_DEBUG_OPTS) $(EXT_LD_OPTS) $(LIBPATH) $(RTLAB_LDFLAGS)


#--------------------------------- Rules ---------------------------------

ifeq "$(UNAME)" "QNX"		##### nto
include posix.rules
else
ifeq "$(UNAME)" "Linux"	##### Linux (RedHawk)
include posix.rules
else
include win32.rules

# Libraries:
ifeq ($(OP_MATLABR12),1)
export MATLAB = $(MATLAB_ROOT)
export RTW_CC = $(CC)
export RTW_CFLAGS = $(CFLAGS)
export RTW_LIBCMD = $(LIBCMD) /nologo /out:$(RTWLIB)
$(RTWLIB) :
	@echo ### Creating $(RTWLIB)
	$(PERL) $(LIBSRC)\mklib.pl $(LIBSRC) $@

else
MODULES_rtwlib = \
	rt_atan2.obj \
	rt_atan232.obj \
	rt_backsubcc_dbl.obj \
	rt_backsubcc_sgl.obj \
	rt_backsubrc_dbl.obj \
	rt_backsubrc_sgl.obj \
	rt_backsubrr_dbl.obj \
	rt_backsubrr_sgl.obj \
	rt_enab.obj \
	rt_forwardsubcc_dbl.obj \
	rt_forwardsubcc_sgl.obj \
	rt_forwardsubcr_dbl.obj \
	rt_forwardsubcr_sgl.obj \
	rt_forwardsubrc_dbl.obj \
	rt_forwardsubrc_sgl.obj \
	rt_forwardsubrr_dbl.obj \
	rt_forwardsubrr_sgl.obj \
	rt_hypot.obj \
	rt_hypot32.obj \
	rt_i32zcfcn.obj \
	rt_intrp1flatcd.obj \
	rt_intrp1flatcf.obj \
	rt_intrp1flatd.obj \
	rt_intrp1flatf.obj \
	rt_intrp1lincd.obj \
	rt_intrp1lincf.obj \
	rt_intrp1linxd.obj \
	rt_intrp1linxf.obj \
	rt_intrp2flatcd.obj \
	rt_intrp2flatcf.obj \
	rt_intrp2flatd.obj \
	rt_intrp2flatf.obj \
	rt_intrp2lincd.obj \
	rt_intrp2lincf.obj \
	rt_intrp2lind.obj \
	rt_intrp2linf.obj \
	rt_intrp2linxd.obj \
	rt_intrp2linxf.obj \
	rt_intrp3lind.obj \
	rt_intrp3linf.obj \
	rt_intrp4lind.obj \
	rt_intrp4linf.obj \
	rt_intrp5lind.obj \
	rt_intrp5linf.obj \
	rt_intrpnflatcd.obj \
	rt_intrpnflatcf.obj \
	rt_intrpnflatd.obj \
	rt_intrpnflatf.obj \
	rt_intrpnlincd.obj \
	rt_intrpnlincf.obj \
	rt_intrpnlind.obj \
	rt_intrpnlinf.obj \
	rt_intrpnlinxd.obj \
	rt_intrpnlinxf.obj \
	rt_intrpnspld.obj \
	rt_intrpnsplf.obj \
	rt_logging.obj \
	rt_look.obj \
	rt_look1d.obj \
	rt_look1d32.obj \
	rt_look2d32_general.obj \
	rt_look2d32_normal.obj \
	rt_look2d_general.obj \
	rt_look2d_normal.obj \
	rt_look32.obj \
	rt_lookflat1bincsd.obj \
	rt_lookflat1bincsf.obj \
	rt_lookflat1binczd.obj \
	rt_lookflat1binczf.obj \
	rt_lookflat1evncsd.obj \
	rt_lookflat1evncsf.obj \
	rt_lookflat1evnczd.obj \
	rt_lookflat1evnczf.obj \
	rt_lookflat1lincsd.obj \
	rt_lookflat1lincsf.obj \
	rt_lookflat1linczd.obj \
	rt_lookflat1linczf.obj \
	rt_lookflat2bincsd.obj \
	rt_lookflat2bincsf.obj \
	rt_lookflat2binczd.obj \
	rt_lookflat2binczf.obj \
	rt_lookflat2evncsd.obj \
	rt_lookflat2evncsf.obj \
	rt_lookflat2evnczd.obj \
	rt_lookflat2evnczf.obj \
	rt_lookflat2lincsd.obj \
	rt_lookflat2lincsf.obj \
	rt_lookflat2linczd.obj \
	rt_lookflat2linczf.obj \
	rt_lookflatnbincsd.obj \
	rt_lookflatnbincsf.obj \
	rt_lookflatnbinczd.obj \
	rt_lookflatnbinczf.obj \
	rt_lookflatnevncsd.obj \
	rt_lookflatnevncsf.obj \
	rt_lookflatnevnczd.obj \
	rt_lookflatnevnczf.obj \
	rt_lookflatnlincsd.obj \
	rt_lookflatnlincsf.obj \
	rt_lookflatnlinczd.obj \
	rt_lookflatnlinczf.obj \
	rt_looklin1bincsd.obj \
	rt_looklin1bincsf.obj \
	rt_looklin1binczd.obj \
	rt_looklin1binczf.obj \
	rt_looklin1binxsd.obj \
	rt_looklin1binxsf.obj \
	rt_looklin1binxzd.obj \
	rt_looklin1binxzf.obj \
	rt_looklin1evncsd.obj \
	rt_looklin1evncsf.obj \
	rt_looklin1evnczd.obj \
	rt_looklin1evnczf.obj \
	rt_looklin1evnxsd.obj \
	rt_looklin1evnxsf.obj \
	rt_looklin1evnxzd.obj \
	rt_looklin1evnxzf.obj \
	rt_looklin1lincsd.obj \
	rt_looklin1lincsf.obj \
	rt_looklin1linczd.obj \
	rt_looklin1linczf.obj \
	rt_looklin1linxsd.obj \
	rt_looklin1linxsf.obj \
	rt_looklin1linxzd.obj \
	rt_looklin1linxzf.obj \
	rt_looklin2bincsd.obj \
	rt_looklin2bincsf.obj \
	rt_looklin2binczd.obj \
	rt_looklin2binczf.obj \
	rt_looklin2binxsd.obj \
	rt_looklin2binxsf.obj \
	rt_looklin2binxzd.obj \
	rt_looklin2binxzf.obj \
	rt_looklin2evncsd.obj \
	rt_looklin2evncsf.obj \
	rt_looklin2evnczd.obj \
	rt_looklin2evnczf.obj \
	rt_looklin2evnxsd.obj \
	rt_looklin2evnxsf.obj \
	rt_looklin2evnxzd.obj \
	rt_looklin2evnxzf.obj \
	rt_looklin2lincsd.obj \
	rt_looklin2lincsf.obj \
	rt_looklin2linczd.obj \
	rt_looklin2linczf.obj \
	rt_looklin2linxsd.obj \
	rt_looklin2linxsf.obj \
	rt_looklin2linxzd.obj \
	rt_looklin2linxzf.obj \
	rt_looklinnbincsd.obj \
	rt_looklinnbincsf.obj \
	rt_looklinnbinczd.obj \
	rt_looklinnbinczf.obj \
	rt_looklinnbinxsd.obj \
	rt_looklinnbinxsf.obj \
	rt_looklinnbinxzd.obj \
	rt_looklinnbinxzf.obj \
	rt_looklinnevncsd.obj \
	rt_looklinnevncsf.obj \
	rt_looklinnevnczd.obj \
	rt_looklinnevnczf.obj \
	rt_looklinnevnxsd.obj \
	rt_looklinnevnxsf.obj \
	rt_looklinnevnxzd.obj \
	rt_looklinnevnxzf.obj \
	rt_looklinnlincsd.obj \
	rt_looklinnlincsf.obj \
	rt_looklinnlinczd.obj \
	rt_looklinnlinczf.obj \
	rt_looklinnlinxsd.obj \
	rt_looklinnlinxsf.obj \
	rt_looklinnlinxzd.obj \
	rt_looklinnlinxzf.obj \
	rt_looksplnbincsd.obj \
	rt_looksplnbincsf.obj \
	rt_looksplnbinczd.obj \
	rt_looksplnbinczf.obj \
	rt_looksplnbinssd.obj \
	rt_looksplnbinssf.obj \
	rt_looksplnbinszd.obj \
	rt_looksplnbinszf.obj \
	rt_looksplnbinxsd.obj \
	rt_looksplnbinxsf.obj \
	rt_looksplnbinxzd.obj \
	rt_looksplnbinxzf.obj \
	rt_looksplnevncsd.obj \
	rt_looksplnevncsf.obj \
	rt_looksplnevnczd.obj \
	rt_looksplnevnczf.obj \
	rt_looksplnevnssd.obj \
	rt_looksplnevnssf.obj \
	rt_looksplnevnszd.obj \
	rt_looksplnevnszf.obj \
	rt_looksplnevnxsd.obj \
	rt_looksplnevnxsf.obj \
	rt_looksplnevnxzd.obj \
	rt_looksplnevnxzf.obj \
	rt_looksplnlincsd.obj \
	rt_looksplnlincsf.obj \
	rt_looksplnlinczd.obj \
	rt_looksplnlinczf.obj \
	rt_looksplnlinssd.obj \
	rt_looksplnlinssf.obj \
	rt_looksplnlinszd.obj \
	rt_looksplnlinszf.obj \
	rt_looksplnlinxsd.obj \
	rt_looksplnlinxsf.obj \
	rt_looksplnlinxzd.obj \
	rt_looksplnlinxzf.obj \
	rt_lu_cplx.obj \
	rt_lu_cplx_sgl.obj \
	rt_lu_real.obj \
	rt_lu_real_sgl.obj \
	rt_matdivcc_dbl.obj \
	rt_matdivcc_sgl.obj \
	rt_matdivcr_dbl.obj \
	rt_matdivcr_sgl.obj \
	rt_matdivrc_dbl.obj \
	rt_matdivrc_sgl.obj \
	rt_matdivrr_dbl.obj \
	rt_matdivrr_sgl.obj \
	rt_matmultandinccc_dbl.obj \
	rt_matmultandinccc_sgl.obj \
	rt_matmultandinccr_dbl.obj \
	rt_matmultandinccr_sgl.obj \
	rt_matmultandincrc_dbl.obj \
	rt_matmultandincrc_sgl.obj \
	rt_matmultandincrr_dbl.obj \
	rt_matmultandincrr_sgl.obj \
	rt_matmultcc_dbl.obj \
	rt_matmultcc_sgl.obj \
	rt_matmultcr_dbl.obj \
	rt_matmultcr_sgl.obj \
	rt_matmultrc_dbl.obj \
	rt_matmultrc_sgl.obj \
	rt_matmultrr_dbl.obj \
	rt_matmultrr_sgl.obj \
	rt_matrx.obj \
	rt_nrand.obj \
	rt_plookbincd.obj \
	rt_plookbincf.obj \
	rt_plookbinkcd.obj \
	rt_plookbinkcf.obj \
	rt_plookbinxd.obj \
	rt_plookbinxf.obj \
	rt_plookevncd.obj \
	rt_plookevncf.obj \
	rt_plookevnkcd.obj \
	rt_plookevnkcf.obj \
	rt_plookevnxd.obj \
	rt_plookevnxf.obj \
	rt_plooklincd.obj \
	rt_plooklincf.obj \
	rt_plooklinkcd.obj \
	rt_plooklinkcf.obj \
	rt_plooklinxd.obj \
	rt_plooklinxf.obj \
	rt_printf.obj \
	rt_sat_div_int16.obj \
	rt_sat_div_int32.obj \
	rt_sat_div_int8.obj \
	rt_sat_div_uint16.obj \
	rt_sat_div_uint32.obj \
	rt_sat_div_uint8.obj \
	rt_sat_prod_int16.obj \
	rt_sat_prod_int32.obj \
	rt_sat_prod_int8.obj \
	rt_sat_prod_uint16.obj \
	rt_sat_prod_uint32.obj \
	rt_sat_prod_uint8.obj \
	rt_tdelay.obj \
	rt_urand.obj \
	rt_zcfcn.obj \


$(RTWLIB) : 
	@echo ### Creating $@
	$(CC) $(CFLAGS) $(MATLAB_ROOT)\rtw\c\libsrc\*.c
	$(LIBCMD) /nologo /out:$@ $(MODULES_rtwlib)
	@echo ### Created $@


endif
endif
endif
