function P=defbox(vertex1,vertex2); 
%  DEFBOX: generate an axis aligned box
%  Inputs:
%    vertex1[-1]  = lowest position corner of the box
%    vertex2[ 1]  = highest position corner of the box
%  Outputs:
%    P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] =  box polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  The default values are set:
 
if nargin<2, vertex2=1; elseif nargin<1, vertex1=-1;end;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;end;
 
%  Find the dimension of the space:
 
d=length(vertex1);
 
%  Give warning message and activate SETDELTA if any of the points
%  is outside the $\kappa$ hypercube:
 
if max(max(abs([vertex1,vertex2]')))>(KAPPA+DELTA)*(1+2*d*eps), 
   disp('Message from DEFBOX:');
   warnkap;
   setdelta;
end;
 
mu=eps; % fitting precision
 
%  Check dimensions:
 
[vert1r,vert1c]=size(vertex1); 
[vert2r,vert2c]=size(vertex2); 
vertl=length(vertex1); 
 
%  Deal with 1D special case:
 
if vert1c==1,  
   vtex1=max(vertex1,vertex2);
   vtex2=min(vertex1,vertex2);
   P=[0 eps ;1 vtex1;-1 -vtex2;vtex1 -1;vtex2 -1];return;
end;
 
%  Give warning message if input is incompatible:
 
if ((vert1r~=1 & vert1c~=1) | vertl~=length(vertex2)), 
   disp('Require compatible vertices in DEFBOX.'); 
   break; 
end; 
 
%  Solution in the 1D case:
 
if (vertl==1), 
  P=[2 mu; 1 max(vertex1,vertex2); -1 -min(vertex1,vertex2)]; 
  return; 
end 
 
%  Transpose if needed:
 
if (vert1r==1), vertex1=vertex1'; ,end; 
if (vert2r==1), vertex2=vertex2'; ,end; 
 
%  Build  up the hyperplane matrix:
 
R=[-eye(vertl),-min([vertex1';vertex2'])']; 
R=[R;eye(vertl),max([vertex1';vertex2'])']; 
 
%  Build  up vertex array recursively:
 
S=[vertex1(vertl-1)*[1 1];vertex1(vertl),vertex2(vertl)]; 
for i=2:vertl-1, 
   [br,bc]=size(S); 
   hS=vertex1(vertl-i)*ones(1,2*bc); 
   S=[hS;S,[vertex2(vertl-i+1)*ones(1,bc);S(2:br,:)]]; 
end; 
S=[[S,(vertex1+vertex2)*ones(1,2^(vertl-1))-S];-ones(1,2^vertl)]; 
 
%  Build  up the polytope representation:
 
P=[[0,2*vertl,mu,zeros(1,vertl-2)];R;S']; 
  
return; 
 
