function P=defpipe(b1,A,b2);
%   DEFPIPE: define a parallelepiped
%  Inputs:
%   b1[-1] = left hand side of the inequalities
%    A[1]  = matrix of the inequalities
%   b2[ 1] = right hand side of the inequalities
%  Outputs:
%   P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = paralellepiped polytope
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Set default output:
 
P=[0 eps;1 1;-1 1;-1 -1; 1 -1];
 
%  Set default inputs:
 
if nargin<3, b2=1; 
elseif nargin<2, A=1;
elseif nargin<1 b1=-1;
end;
 
%  Set  global precision bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), 
   setdelta;
end;
 
%  Diagnostics of dimensions:
 
[n,d]=size(A);
if ~((length(b1)==n)&(length(b2)==n)), 
   disp(' Unequal dimensions in "defpipe".');break;
end;
 
%  Build array of facet inequalities:
 
B=[A b2;-A -b1];
 
%  Compute the intersection of half-spaces:
 
P=fconvh(B);
 
return;
 
 
