function U=dif(U1,U2);
%  DIF: compute the set-difference of vector sets
%  Inputs:
%   U1[1] = first set
%   U2[1] = second set
%  Outputs:
%   U[ [] ]  = set difference
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  The global precision bounds are set:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate user interface SETDELTA if not defined:
 
if (isempty(DELTA) | isempty(KAPPA)), 
   setdelta;
end
 
%  Set the default values:
 
if nargin<2, U2=[1];elseif nargin<1, U1=[1];end;
U=[];
 
%  Give warning message if KAPPA-hypercube is exceeded:
 
if max(max(abs(U1)))>KAPPA, warndel;end;
 
%  Find number of points:
 
[n1,d1]=size(U1);[n2,d2]=size(U2);
 
%  Diagnostics:
 
if d1~=d2, 
   disp('Number of columns of arguments must be the same in DIF');
   break;
end;
if n2==0, U=U1;return;end;
if n1==0, U=[];return;end;
 
%  Compare each point in U1 with all points in U2:
 
indu1=ones(n1,1); 
for i=1:n1,
  ind=abs(U2-ones(n2,1)*U1(i,:));
  if min(max(ind'))<DELTA, indu1(i)=0;else indu1(i)=1;end;
end;
indu=indu1>0;
 
%  Define points in U1 which are not in U2:
 
U=U1(indu,:);
 
return;
 
 
