function [vmax,vmin,width]=dirext(G,di);
%  DIREXT:  compute extremal points in a given direction
%  Inputs:
%   G[[1 eps;1 1]] = polytope
%   di[1]          = direction vector
%  Outputs:
%   vmax[1]    = extremum in + direction
%   vmin[1]    = extremum in - direction
%   width[0]   = the width in the direction
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Define default values:
 
if nargin<1, G=[1 eps;1 1];end;
if nargin<2, di=ones(dim(G),1);end;
vmax=1;vmin=1;width=0;
 
%  Check the dimension:
 
[dr,dc]=size(di);
if (dr==1), di=di';dr=dc;dc=1;end; 
[er,ec]=size(G);d=er-1;
 
 
%  Deal with the 1D case:
 
  if (d==1),
    if (di>0),vmax=G(2,2);vmin=-G(3,2);width=G(2,2)+G(3,2);end;
    if (di<0),vmax=-G(3,2);vmin=G(2,2);width=G(2,2)+G(3,2);end;
    return
  end;      
  
%  The general case of d>1. Find the `maximum' vertex:
 
V=vertices(G);V1=V*di;
[a,imax]=max(V1);vmax=V(imax(1),:)';
  
%  Find  the `minimum' vertex:
 
[a,imin]=min(V1);
vmin=V(imin(1),:)';
 
%  Compute the width:
 
if norm(di)>eps, 
	width=abs(di'*(vmax-vmin)/sqrt(di'*di));
else 
	width=0; 
end;
 
return;
 
 
 
 
 
