function [D,ndir]=dirgen(d,n)
%  DIRGEN: generate an approximately uniform set of direction-vectors
%  Inputs:
%    d[1] = dimension
%    n[2] = number of directions for each dimension
%  Outputs:
%    D  =  set of row direction vectors
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Set the default values:
 
if nargin<2, n=2;elseif nargin<1, d=1;end;
D=[1;-1];
 
%  Do diagnostics:
 
if (d<2),disp('Dimension must be at least 2');break;end;
if (n<2),disp('Number of directions must be at least 2');break;end;
 
%  Generate directions:
 
D=zeros(2*n,2); % initialise an array of directions
alp=pi*(1:2*n)/n;
 
%   Deal with 2D case is done first, generate `2n' uniform directions in circle:
 
for j=1:2*n,
  D(j,:)=[cos(alp(j)) sin(alp(j))];
end;
 
%   In the 3+ dimensions  the matrix D is built up by adding `n' new
%   directions in each new dimension :
 
for i=2:d-1,
  D1=D;D=[zeros(1,i) 1;zeros(1,i) -1];
  [m,mc]=size(D1);
  for j=1:(n-1),
    bet=pi*(j/n-0.5);
    D=[D;D1*cos(bet) ones(m,1)*sin(bet)];
  end;
end;
ndir=size(D,1);
return;
 
%  If $\gamma(d)$ denotes the number of direction in dimension `d' then
%  $\gamma(2)= 2n$ and the recursion $\gamma(d+1)=\gamma(d)*(n-1)+2$ holds.
 
 
 
