function [e,p,v]=ELLDIFI(e1,e2,rin);
%  ELLDIFI: compute an inner bounding ellipsoid to the difference of two ellipsoids.
%  Inputs:
%    e1[[1 0;1 0]] = first ellipsoid
%    e2[[1 0;1 0]] = second ellipsoid
%     rin['vol']   = criterion (options: rin>0,'vol','tr1',tr2')
%  Outputs:
%    e[[1 0;4 0]]  = outer bounding ellipsoid of the sum
%    p  =  optimisation parameters received
%    v  =  criterion value optimised
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%    Diagnosis:
 
[ro1,co1]=size(e1);[ro2,co2]=size(e2);
if [ro1 co1]~=[ro2 co2], 
  disp('Dimensions of ellipsoids are different.');
  break; 
end;
if isstr(rin) & rin ~= 'vol' & rin ~= 'tr1' & rin ~= 'tr2' 
	disp('Incorrect parameter string.');
	break; 
end;
if ~isstr(rin) & (rin >= -1) ,
	disp('Incorrect parameter value.');
	break; 
end;
 
%     The algorithm of subtracting two ellipsoids:
 
n=ro1-1;
Q1  = e1(2:ro1,1:n);a1=e1(2:ro1,co1);
Q2  = e2(2:ro1,1:n);a2=e2(2:ro1,co1);
Q   = Q1/Q2;
lam = eig(Q);
tol = 10^(-15);
r2  = min(lam);
if r2 < 1 ,
  disp('The difference is empty.');
    break; 
end;
r1  =-sqrt(r2);
r2  =-r2+tol;
if rin == 'vol',
	
%  Calculating parameter for maximal volume:
	
	v1 = det((1+1/r1)*Q1+(1+r1)*Q2);
	v2 = det((1+1/r2)*Q1+(1+r2)*Q2);
	vol = v1;
	r0  = r1;
	if v1 < v2,
		vol = v2;
		r0  = r2;
	end;
	x=-diag(lam(2:n));p=poly(x);
	for i=2:n-1, 
  		p=p+poly(-diag([lam(1:i-1) lam(i+1:n)])); 
	end;
	p=p+poly(-diag(lam(1:n-1)));p=conv(p,[0 1 1]);
	x=-diag(lam);p=p-n*[poly(x) 0];
	r=roots(p);
	for i=1:n+1,
		v0 = det((1+1/r(i))*Q1+(1+r(i))*Q2); 
  		if r(i)< r1 & r(i) > r2 & vol <= v0,
 			vol = v0;
			r0  = r(i); 
		end; 
	end;
	v0 = vol;
elseif rin == 'tr1',
	
%  Calculating the parameter for maximal trace:
	
	v1 = trace((1+1/r1)*Q1+(1+r1)*Q2);
	v2 = trace((1+1/r2)*Q1+(1+r2)*Q2);
	tr1 = v1;
	r0  = r1;
	if v1 < v2 
		tr1 = v2;
		r0  = r2;
	end;
	r  = -sqrt(trace(Q1)/trace(Q2));
	v0 = trace((1+1/r)*Q1+(1+r)*Q2);
	if r < r1 & r > r2 & tr1 <= v0,
		tr1 = v0;
		r0  = r;
	end;
	v0 = tr1;
elseif rin == 'tr2',
	
%  Calculating parameter for maximal trace of square:
	
	v1 = trace(((1+1/r1)*Q1+(1+r1)*Q2)^2);
	v2 = trace(((1+1/r2)*Q1+(1+r2)*Q2)^2);
	tr2 = v1;
	r0  = r1;
	if v1 < v2 
		tr2 = v2;
		r0  = r2;
	end;
	gam11 = trace(Q1*Q1);
	gam12 = trace(Q1*Q2);
	gam22 = trace(Q2*Q2); 
	r     = roots ([gam22 gam12 -gam12 -gam11]); 
	for i=1:3,	
		v0  = trace(((1+1/r(i))*Q1+(1+r(i))*Q2)^2);
		if imag(r(i)) == 0 & r(i) < r1 & r(i) > r2 & tr2 <= v0,
			tr2 = v0;
			r0  = r(i);
		end;
	end;
	v0 = tr2; 
else
	
%  Correcting parameter value given by the user:
	
	r0 = max ([rin  r2]);
	r0 = min ([r0   r1]);
	v0 = 0;
	v1 = 0;
	v2 = 0; 
end;
 
%   Building output ellipsoid:
 
a=a1-a2;
Q=(1+1/r0)*Q1+(1+r0)*Q2;
e=[1 ones(1,n);Q a];
p=[r0 r2 r1];
v=[v0 v2 v1];
return
 
 
 
