function [FV,nh,ne,acc]=fv(H);
%  FV: produce facet-vertex Boolean table of adjacency
%  Inputs:
%   H[[0 eps;1 1;-1 1;-1 -1;1 -1]] =  polytope
%  Outputs:
%   FV[[0 1;1 0]]  = vertex-facet adjacency table
%   nh  = number of face inequalities
%   ne  = number equations
%   acc = largest fitting error of facets-vertices
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Find global numerical bounds:
 
global DELTA;global KAPPA;global KAPPA;global ERRFACTOR;
 
%  Create input and output defaults:
 
if nargin<1, H=[0 eps;1 1;-1 1;-1 -1;1 -1];end;
FV=[0 1;1 0];
 
%  Activate interface if DELTA or KAPPA are undefined:
      
if (isempty(DELTA) | isempty(KAPPA)), setdelta;end;
 
%  Find dimension:
 
d=size(H,2)-1;
 
%  List facets and vertices:
 
[F,nh,ne]=faces(H);[V,nv]=vertices(H);
 
%  Construct the VH adjacency  Boolean table
 
I=F(2*ne+1:nh+2*ne,:)*[V -ones(nv,1)]';
Ind=abs(I)<DELTA*ones(nh,nv);
I=I.*Ind;acc=max(max(abs(I)));
 
%  Construct the FV index table with zero fillups:
 
vmax=max(sum(Ind'));indx=(1:nv);
FV=zeros(nh,vmax);
for i=1:nh, 
   vf=indx(Ind(i,:)); noh=size(vf,2); FV(i,1:noh)=vf;
end;
return
   
 
