function P2=gbt726(P);
%  GBT726: convert GBT 7 format to type 4 format of GBT 6.1
%  Inputs:
%     P[[0 eps;1 1;-1 1;-1 -1; 1 -1]]  = polytope
%  Outputs:
%     P2 = polytope in type 4 format
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Note that  polytopes which
%  have more then $d$ edges meeting at a vertex ($d$ is the dimension),
%  cannot be converted into type 4 format of GBT 6.1 .
 
%  Dimension of representations space:
 
d=size(P,2)-1;
 
%  Compute the vertex-vertex and vertex-facet adjacency tables:
 
[VV,VF,nv,nh]=vvf(P);
 
%  Diagnostics of too many edges to a vertex:
 
if size(VV,2)>d | size(VF,2)>d, 
disp('Type 0 polytope into GBT726 has more');
disp('than "the dimension" facets to a vertex');
disp('Cannot convert into "type 4" format.');
P2=[];
break;
end;
 
%  Diagnostics of dimensionality:
 
if P(1,1)>0, 
disp('Actual dimension of type 0 polytope');
disp('is too small into GBT726.');
disp('Cannot convert into "type 4" format.');
P2=[];
break;
end;
 
%  Perform conversion:
 
F=faces(P);V=vertices(P);
if d>1,
   P2=[4 nh nv zeros(1,d-2);F;V -ones(nv,1);VF zeros(nv,1);VV zeros(nv,1)];
else
   P2=[4 nh;F;V -ones(nv,1);VF zeros(nv,1);VV zeros(nv,2)]; 
end;
return;
 
