function E=intell(C,options),
%  INTELL:  find a maximal volume ellipsoid within a polytope
%  Inputs:
%     C[0 eps;1 1;-1 1;1 1;-1 1]   =    polytope in GBT type 0 format
%      options[1.e-4,150]  = termination tolerance, number of iterations
%  Outputs:
%        E  = ellipsoid
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Define defaults for inputs:
 
if nargin<1, C=[1;-1];end;
if nargin<2,options=[1.e-4,150];end;
 
%  Deal with the 1D case:
 
d=dim(C);
if d==1, V=vertices(C);	r=abs(V(1)-V(2))/2;E=[1 0;r*r mean(V)];
return; end;
 
%  Find the mass centre and shifting the polytope:
 
shift=-mean(vertices(C));
C=ltran(C,eye(d),shift);
C=faces(C);
 
%  Test if mass-centre is internal:
 
if min(C(:,d+1))<eps,
  error('No internal point was found for the polytope in INTELL');
end;
 
%  Normalize the RHS of the inequalities defining the polytope:
 
C=C./(C(:,d+1)*ones(1,d+1));
C=C(:,1:d);nA=d;
 
%  Maximize by the method of successive space dilatation:
  
   X=eye(nA);y=zeros(1,nA); % initialisation of solution
   
%  Start  iterations:
 
   for k=1:options(2),
	   
    if k<min(nA+1,10), w=-0.33;	else w=-1/k;end;
 
	  dC=sqrt(sum((C.*C)'));
	  r=(1-y*C')./dC;
      [m1,i1]=min(r);
      p=m1./r;
	  i2=find(p>0.99);
      if(size(i2,2)>1),
		  z=sum(diag(p(i2))*C(i2,:));
		  nz=norm(z);
      else 
		  z=C(i2,:);nz=dC(i2);
      end;
      if(nz>1.e-10)y=y+(w*m1/nz)*z;end;
      z=C(i1,:)/dC(i1);
	  C=C+w*(C*z')*z;X=X+w*(X*z')*z;
      y=y-(w*(y*z')/(1+w))*z;
   end;
   [m1,i1]=min((1-y*C')./sqrt(sum((C.*C)')));
   E=[1,zeros(1,nA);X*X'*(m1*m1),X*y'];
 
%  Shift back the solution ellipsoid:
   
  E=elltran(E,eye(d),-shift');
  
  
 return;
