function p=intpoint(P);
%  INTPOINT: find an internal point within a polytope
%  Inputs:
%    P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = polytope
%  Outputs:
%    p   =  internal point
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Finding global numerical bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate interface if any of the bounds is undefined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;P=[];end;
 
%  Deal with the lower dimensional case:
 
[d,ad]=dim(P);if d-ad>0, p=[];return;end;
 
%  List the vertices:
 
[V,nv]=vertices(P);
p=mean(V);
 
%  Test `p' for DELTA-internal point:
 
F=faces(P);
de0=max(F*[p -1]');
 
%  If mean of vertices is not a DELTA internal point then generate
%  1000 random points near the mean to find a suitable point.
 
if de0>-DELTA,
   p0=p;
   for i=1:1000,
      p1=p+d*(DELTA*rand(1,d)-0.5);
      de=max(abs(F*[p1 -1]'));
      if de<-DELTA, p=p1;return;end;
      if de<de0, p=p1;de0=de;end;
   end;
   disp('Internal point was not found in INTPOINT');p=[];
end;
 
return;
 
