function [x,f]=lpcent(A,p,options),
%  LPCENT: calculate the lp-centre of a set of points
%   Inputs:
%     A     =     a set of points
%     p[2]  =     norm-parameter p>=1 ,
%  options[1.e-4,150] =  tolerance and max. no. iterations
%   Outputs:
%     x    =     center of `convh(A)'
%     f    =     radius of `convh(A)'
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Dealing with a single points:
 
if(size(A,1)==1),x=A;f=0;return;end;
 
%  Start processing for multiple points:
 
if (nargin<2)|(p<1),
	
%  Computate of $l_{infty}$ centre 	
	
y1=max(A);y2=min(A);x=0.5*(y1+y2);f=max(0.5*(y1-y2));
	
else
 
%  Start  iterative algorithm
 
   if(nargin<3)options=[1.e-4,150];end;
   x=ones(1,size(A,2));
   h=-0.01;w=-0.66;n=size(x,2);k=0;
   while 1,
      B=eye(n);
      [f,g]=f_lp(x,A,p);
      g1=g;
      if(norm(g1)<1.e-10)return,end;
      dx=-h*sqrt(3);
 
%  Do main iteration:
 
   while 1,
         k=k+1;
         g=g*B;
         z=g-g1;
         nz=norm(z);
         if(nz>1.e-10),z=z/nz;else z=zeros(1,n);end;
         g1=g+w*(z*g')*z;
         d1=norm(g1);
         if(d1<1.e-10),h=-dx/3;k=k-1;break;end;
         B=B+w*(B*z')*z;
         g0=(g1/d1)*B';
         k1=0;z=x;
   
%  Move in a constant direction:
 
         while 1,
            x=x+h*g0;
            [f,g]=f_lp(x,A,p);
            k1=k1+1;
            if(k1>3),h=1.2*h;end;
            if((g0*g')<1.e-20),break;end;
         end;
         dx=norm(z-x);
         if(dx<options(1)),f=f^(1/p);return,end;
         if(k==options(2)),f=f^(1/p);
             disp('After maximal number of iterations:');
             return,
         end,
      end,
   end,
 
 
end;
