function [Pt,acc]=ltran(P,A,a,typ);
%  LTRAN: perform affine transformation on a polytope
%  Inputs:
%    P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = polytope
%    A[1]  = transform matrix
%    a[0]  = offset vector after transformation
%  Outputs:
%    Pt[[0 eps;1 1;-1 1;-1 -1; 1 -1]]   = transformed polytope
%    acc[eps] = error bound of vertex-facet adjacency
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
%  Find global numerical bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Activate interface if any of the bounds is undefined:
 
if (isempty(DELTA) | isempty(KAPPA)), setdelta;P=[];end;
 
%  Find out dimensions, vertices and facets:
 
[nr,d1]=size(P);d=d1-1;
[V,nv]=vertices(P);[F,nf,ne]=faces(P);
 
%  Diagnose input variables:
 
[na,d2]=size(A); 
if nargin > 2,
   [naa,nca]=size(a);if naa<2, a=a';naa=nca;end;
else
   a=zeros(na,1);[naa,nca]=size(a);
end;
if nargin<4, typ='numer';end;
acc=eps;
 
if ~(d==d2), disp('Dimensions incompatible in ATRAN.');pause;end;
if ~(naa==na), disp('Dimensions incompatible in ATRAN.');
   pause;end;
 
%  Analyse the case of square and nonsingular `A' :
 
co=cond(A);
if na==d2 & co < 0.001/DELTA,
   A1=inv(A); Pt=P;
   ne=P(1,1); Pt(2:1+ne+nf,1:d)=P(2:1+ne+nf,1:d)*A1;
   Pt(2:1+ne+nf,d+1)=P(2:1+ne+nf,d+1)+P(2:1+ne+nf,1:d)*A1*a;
   for i=2:1+ne+nf, 
      Pt(i,:)=Pt(i,:)/norm(Pt(i,1:d));
   end;
   Pt(2+ne+nf:nr,1:d)=P(2+ne+nf:nr,1:d)*A'+ones(nr-ne-nf-1,1)*a';
   Pt(1,3)=co*P(1,3);
   return;
end;
 
%  Test for the size of vertices of the transformed polytope:
 
Vp=V*A'+ones(nv,1)*a';
if max(max(abs(Vp)))>KAPPA, warnkap;end;
Av=Vp-ones(nv,1)*Vp(1,:);  % examining the relative size
if max(max(abs(Av)))>KAPPA, warnkap;end;
 
%  Start of procedure followed for the degenerate case:
 
[Pt,ac]=convh(Vp,typ);
if ac>acc, acc=ac;end;
   
%  Give error message if global DELTA is violated:
   
if acc>DELTA, warndel;end;
return;
      
 
 
