function [P1,affsbsp]=mindim(P);
%  MINDIM: minimize the dimension of the representation of a polytope
%   Inputs:
%      P[[1 eps;1 0]]  = polytope
%   Outputs:
%      P1[0]       = polytope
%   affsbsp[[1 0]] = equation of affine subspace
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%   Diagnose  simple cases:
 
if isempty(P), P1=[];affsbsp=0;return;end;
if size(P,1)==1 & size(P,2)==1, P1=0;affsbsp=0;return;end;
 
%  Find the dimension of representation:
 
d=dim(P);
 
%  If the polytope is full dimensional then the output polytope is the
%  same and the subspace is the whole of $Re^d$ which is represented
%  by a length $d+1$ zero vector:
 
if P(1,1)==0, P1=P;affsbsp=zeros(1,d+1);return;end;
 
%  The degree of singularity = $ d - $(dimension of the smallest submanifold
%  containing the polytope ) is denoted by $l$ :
 
l=P(1,1);
 
%  The left hand side of the equality system:
 
N=P(2:l+1,1:d);
 
%  The right hand side of the equality system (offset):
 
offs=P(2:l+1,d+1); affsbsp=[N offs];  % = equations of the affine subspace
 
%  Compute singular value decomposition of the right hand side:
 
[U,S,V1]=svd(N');
 
%  Find vertices of the polytope:
 
V=vertices(P);
 
%  Extract the facet inequalities of the polytope  into `F':
 
[F,nf]=faces(P);F=F(2*l+1:nf+2*l,:); % nf = number of proper inequalities 
 
%  Project the vertices into the $d-l$
%  dimensional subspace:
 
newV=V*U;
vdistanc=mean(newV(:,1:l)); % = the shared part of the new vertices
newV=newV(:,l+1:d);
 
%  Initialize the size of `newF' :
 
newF=zeros(0,d+1-l);
 
%  Build up the new set of facets:
 
for i=1:nf,
  anew=F(i,1:d)*U;
  nrm=norm(anew(l+1:d));
  acomp=anew(1:l);
  anew=anew(l+1:d);
  bnew=F(i,d+1)-vdistanc*acomp';
  newF=[newF;anew/nrm bnew/nrm];
end;
 
%  Construct the polytope representations:
 
if d-l==1, P1=[0 eps; newF ;newV -ones(size(newV,1),1)];end;
if d-l>=2, P1=[0 nf P(1,3) zeros(1,d-l-2); newF ;newV -ones(size(newV,1),1)];end;
if d-l==0, P1=[0];end;
return;
