function [plist,vlist]=planeigh(P,plno);
%  PLANEIGH: list neighbouring facet planes
%  Inputs:
%    P[[1 0;1 0]] = polytope
%    plno[1]      = index of facet
%  Outputs:
%    plist[[-1 0]]] = facet-plane equations of neighbouring facets
%    vlist[1]       = index list of vertices on facet
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%   Default index of facet:
 
if nargin<2, plno=1;end;
 
%  Find dimension of space:
 
d=dim(P);
 
%  Construct the facet-vertex adjacency table:
 
[fvl,nf,ne]=fv(P);
 
%  List vertices adjacent with facet `plno':
 
vlist=setdiff(fvl(plno,:),[0]);
 
%  Construct list of facet indices:
 
plist=[];
for i=1:nf, 
  if i~=plno, 
     if length(setdiff(intersect(fvl(i,:),fvl(plno,:)),[0]))>d-ne-1.5,
       plist=[plist i];
     end;
  end;
end;
return; 
          
