function [D,acc]=poldual(P);
%   POLDUAL: compute the dual of a polytope
%   Inputs:
%     P[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = polytope
%   Outputs:
%     D[[0 eps;1 1;-1 1;-1 -1; 1 -1]] = dual of a polytope
%           acc      = max. error of vertex-facet adjacency
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Define default input:
 
if nargin<2, O2=[1 eps;1 0];end;
 
%  Find global precision bounds:
 
global DELTA;global KAPPA;global ERRFACTOR;
 
%  Find the dimensions and errror parameters:
 
[n,d1]=size(P);d=d1-1;
if d==1, acc=P(1,2); else acc=P(1,3);end;
[F,nf]=faces(P);e=min(F(:,d1));
 
%  Give warning messages:
 
if e<DELTA, 
   disp('Polytope in POLDUAL must contain the origin'); break;
end;
 
%  List the vertices, giving warning if necessary:
 
[V,nv]=vertices(P);if max(max(abs(V)))>KAPPA, warndel;end; 
 
 
%  Build up the facet list of the dual polytope:
 
v=(1:nv)';for i=1:nv, v(i)=1/norm(V(i,:));end;
A=[V.*(v*ones(1,d)) v];
 
%  Construct the dual polytope for dimensions 1  and >1 :
 
if d==1,
   acc=eps/e;
   D=[0 acc;P(2:3,1) [1 1]';P(2,1)/P(2,3) P(3,1)/P(3,2) ];
else
   acc=P(1,3)/e;
   F=F(:,1:d)./(F(:,d1)*ones(1,d));
   F=[F -ones(nf,1)];
   D=[0 nv acc zeros(1,d1-3);A;F];
end;  
 
%  Set the new error bounds:
 
[afv,nh,ne,acc]=fv(P);
 
return;
 
