function Pp=projpol(P,spanvecs,offset);
%  PROJPOL: project polytope onto linear manifold
%   Inputs:
%      E[[1 0;1 0]  = ellipsoid
%     spanvecs  = spanning vectors of subspace
%      offset   = point in manifold
%   Outputs:
%       Pp   = projected polytope in same dimension
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Finding dimensions:
 
if size(spanvecs,1)<size(spanvecs,2), spanvecs=spanvecs';end;
if size(offset,2)==1, offset=offset;end;
[d,d_new]=size(spanvecs);
 
%   Producing transformation matrix:
 
S=spanvecs;
T=S*pinv(S'*S)*S';
 
%  Producing the base point in manifold:
 
[u,d,O]=svd(S');obase=O(:,d_new+1:d);
v0=obase*(obase'*offset');
 
%   Transforming the vertices:
 
[V,nv]=vertices(P);
Vnew=V*T'+ones(nv,1)*v0';
 
%   Computing convex hull:
 
Pp=convh(Vnew);
return;
 
