function [A,Area2]=surfarea(P);
%  SURFAREA: compute the surface area of a polytope
%  Inputs:
%    P[[1 0;0 1]] = polytope
%  Outputs:
%    A[0]   = surface area
%    Arel[0] = relative surface area
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
%  Do diagnostics:
 
if isempty(P), A=0;Area2=0;return;end;
 
%  Find dimension and reduce P to its minimal actual dimension:
 
d=dim(P);P1=mindim(P);
 
%  Deal with special case:
 
if isempty(P1), A=0;Arel=0;return;end;
 
%  Find dimension of `P1' :
 
d1=dim(P1);
 
%  For ``thin'' object (i.e. dimension =d) set the surface A to be the volume:
 
if d1==d-1, A=polvol(P1);Area2=surfarea(P1);return;end;
 
%  For ``very thin'' object (i.e. dimension <d-1) define the surface A=0 :
 
if d1<d-1, A=0; Area2=polvol(P1);return;end; 
 
%  For full-dimensional polytope the surface-area is the sum of
%  the ``volumes'' of all of its facets:
 
[F,nf]=faces(P);A=0;
for i=1:nf,
  F1=facet(P,i);A=A+polvol(F1); 
end;
Area2=A;
return;
  
 
