function [Pup,acc]=update(h,P,typ,spd);
%  UPDATE: compute the intersection of a half-space and a polytope
%  Inputs:
%     h[[1 0]] = half-space inequality
%     P[[1 eps;1 0]] = polytope
%     typ['numer']  = type of operation
%     spd = 1 if speed = 0 if memory is preferred
%  Outputs:
%   Pup[[1 eps;1 0]] =  updated polytope
%   acc[eps] = maximum error of adjacency of vertices and facets
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
 
global DELTA;global KAPPA;global ERRFACTOR;global COMPLX;global MAXSIZE;
 
 
if (isempty(DELTA) | isempty(KAPPA) | isempty(ERRFACTOR)), H=[];setdelta;end;
 
 
 if isempty(P), Pup=P;acc=eps; return; end;
 if nargin<3, typ='numer';end;
 if nargin>3, fastm=spd;else fastm=0>1;end;
 arrsize(P);
 
 
[nr,d]=size(P);d=d-1;
 
 
[Vold,nvold]=vertices(P);
 
 
 if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('  UPDATE started at %2i hrs %2i min %2.3f sec with %5i vertices of the polytope.\n',cl(4:6),nvold);
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
 
if max(max(abs(Vold)))>(KAPPA+DELTA)*(1+2*d*eps), 
  (max(max(abs(Vold))))/eps
  warnkap; disp('This message is from UPDATE');
  setdelta;
 
 
  [Fold,nofold]=faces(P);
  
  
  P=defbox(-KAPPA*ones(1,d),KAPPA*ones(1,d));
  
  
  for i=1:nofold, P=update(Fold(i,:),P); end;
  
  
  PuP=update(h,P);
  return;
  
end;
 
 
if nargin<2,  error('Not enough input variables in UPDATE');end;
 
 
if d>1, acc=P(1,3);else acc=P(1,2);end;
 
 
[h,acc1]=hadjust(h,P);acc=max(acc,acc1);
if size(h,1)==1, h=h';end; % transpose if necessary
 
 
if norm(h(1:d))<d*DELTA, 
   error('Updating with low precision half-space in UPDATE');
   return;
else
   hn=norm(h(1:d));
   h=[ h(1:d)/hn ; h(d+1)/hn ];
end;
 
 
if d>1,
   nv=nr-P(1,1)-P(1,2)-1;
   F=P(2+P(1,1):1+P(1,1)+P(1,2),:);
   V=P(2+P(1,1)+P(1,2):nr,:);
   indout=V*h>=DELTA;     % = Boolean table of vertices outside
   indon=abs(V*h)<DELTA; % = Boolean table of vertices on the border
   indin=V*h<=-DELTA;     % = Boolean table of vertices inside
   if fastm, 
      [VV,VF]=vvf(P); % = vertex-vertex & vertex facet adjacency
   else
      [VV,VF]=vvf_2(P);
   end;
   arrsize(VV);arrsize(VF);
          
   vvn=size(VV,2);
   
 
if sum(indin | indon)==nv, Pup=P;acc=P(1,3);return;end;   
if sum(indin | indon)<1, 
   Pup=[ ];acc=eps;return;
else
   Vh=[ ];nonw=0;
   for i=1:nv,
      if indin(i),
         for j=1:vvn,
            if VV(i,j)>0.5,
               if indout(VV(i,j)),
                  FF=intersect(VF(i,:),VF(VV(i,j),:));
                  if FF(1)==0, FF=FF(2:length(FF)); end;
                  FFF=[F(FF,:);h'];   
                  [newvert,fitacc]=vtxfit(FFF); % computes new vertex
                  Vh=[Vh;newvert];nonw=nonw+1;
                  acc=max([acc fitacc]);              
               end;
            end;
         end;
      end;
   end;
end;
   
 
Vhones=-ones(size(Vh,1),1); 
Vnew=[V(indin | indon,:); Vh Vhones]; % new set of vertices
 
 
nonv=size(Vnew,1);noof=size(F,1); 
IndM=VF(indout,:);
[nr,nc]=size(IndM); 
BoolF=zeros(noof,1)>1;
for i=1:nr, 
   for j=1:nc, 
      if IndM(i,j)>0.5, BoolF(IndM(i,j))=1>0;end;  
   end;
end;
 
 
IndN=VF(indin,:);[nr,nc]=size(IndN); 
BoolN=zeros(noof,1)>1;  % initialisation
for i=1:nr, 
   for j=1:nc, 
      if IndN(i,j)>0.5, 
		  BoolN(IndN(i,j))=1>0; %=1 if `i' adjacent outside `j'
	  end;  
   end;
end;
 
 
Ftest=~(~BoolN & BoolF);Fnew=F(Ftest,:);
nofnew=size(Fnew,1);noeq=P(1,1);
Pup=[P(1,1) nofnew+1 acc zeros(1,d-2);
     P(2:1+noeq,:);
     h';
     Fnew;
     Vnew ];
arrsize(Pup);    
 
	 
  if rank(Vnew(:,1:d),2*DELTA) < d-P(1,1), 
     Pup=convh([V(indin,1:d);Vh]);
     return;
  end;
  
  if ~isempty(COMPLX), 
    fid=fopen('complex.txt','a');
    cl=clock;
    lin=sprintf('     UPDATE finished %2i hrs %2i min %2.3f sec.\n',cl(4:6));
    disp(lin);
    fprintf(fid,lin);
    fclose(fid);   
 end;
 
 
  
if acc>DELTA, warndel;
disp('(...message from UPDATE at end of routine)');end; 
return;
end; % if d>1
 
 
if d==1,
   if abs(h(1))<DELTA, Pup=P;acc=eps;return;end;
   if P(1,1)<0.5,
      newp=h(2)/h(1);
      if h(1)>0, 
         vtop=min([max(P(4:5,1)) newp]);
         vl=min(P(4:5,1));
         if abs(vtop-vl)<DELTA,
            Pup=[1 eps;1 vl]; 
            return;
         end;
         if newp<vl-DELTA, Pup=[ ];return;end;
         Pup=[0 eps;1 vtop;-1 -vl; vl -1;vtop -1]; 
      else
         vbot=max([min(P(4:5,1)) newp]);
         vh=max(P(4:5,1));
         if abs(vbot-vh)<DELTA,P=[1 eps;1 vh];acc=eps;return;end;
         if newp>vh+DELTA, Pup=[ ];return;end;
         Pup=[0 eps;1 vh;-1 -vbot; vbot -1; vh -1]; 
      end;
   end;
   acc=eps;
return; 
end;
return;
