function [x1,acc]=vadjust(x,P,typ);
%  VADJUST:  adjust a point with respect to facet-hyperplanes of a polytope
%  Inputs:
%     x     - a point
%     P     - a polytope
%   typ['numer']  = type of operation
%  Outputs:
%   x1    - adjusted point
%   acc   - fitting accuracy of adjusted point
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
 global DELTA;global KAPPA;global ERRFACTOR;
 if nargin<3, typ='numer';end;
 
 
 
if (isempty(DELTA) | isempty(KAPPA)), H=[];setdelta;end;
 
 
[nr,d]=size(P);d=d-1;
 
 
[F,nf]=faces(P);
 
 
B=abs(F*[x'; -1])<DELTA;
H1=F(B,1:d);H2=F(B,d+1);
 
 
if sum(B)>0,
   x1=x'-H1'*pinv(H1*H1')*(H1*x'-H2);x1=x1';
   acc=max(max(abs(H1*x1'-H2)));
else
   x1=x;acc=eps;
end;
 
H_=F(~B,:);B_=abs(H_*[x1';-1])<DELTA;
nh=sum(B_);if nh<1, return;end;
 
 
cP=mean(vertices(P));nm=norm(x1-cP);nmv=(x1-cP)/nm;
 
 
if nh>0 & typ=='inter', 
   
   while nh>0,
      
      x1=x1-ERRFACTOR*DELTA*nmv;
      B_=abs(F*[x1';-1])<DELTA;
      nh=sum(B_);if nh<1, return;end;
      
   end;
   
elseif nh>0 & typ=='outer',
   
    while nh>0,
      
      x1=x1+ERRFACTOR*DELTA*nmv;
      B_=abs(F*[x1';-1])<DELTA;
      nh=sum(B_);if nh<1, return;end;
      
    end;
   
else
   
   [U,D,V]=svd(H1);H1c=V(:,size(H1,1)+1:d);
   
    cnt=1;
    while nh>0,
      nmv=H1c*(2*rand(size(H1c,2),1)-1);
      x1=x1+DELTA*nmv';cnt=cnt+1;
      B_=abs(F*[x1';-1])<DELTA;
      nh=sum(B_);if nh<1, return;end;
      if cnt>100,
        disp('   ');
        disp('Numerically extra hard problem encountered in VADJUST...  ');
        disp('Switch to the use of  typ="inter" or typ="outer"');
        disp('for the type of operation in FCONVH, UPDATE or CONVH, P_CONV ,');
        disp('depending on whether inner or outer bounding is');
        disp('suitable in your application.');
        error('Cannot continue without "typ" being redefined...'); 
      end;
    end;
 
end;
return;
