function [axout,ellip]=view2del(E,a,col,axin,styl,resol,aequal);
%  VIEW2DEL: display 2D views of ellipsoids
%   Inputs:
%     E[[1 0 0;1 0 0;0 1 0]] = ellipsoid
%     a[[1 2]]  =  axis of 2D projections
%      col['blue']   = color of ellipsoid
%     axin      =  object handle of axes
%      styl['-']      = linestyle
%     resol[100]     = resolution of plot
%     aequal[0]    =  axis equal setting
%   Outputs:
%     axout   =  axes handle
%      ellip  =  object handle of ellipsoid
% 
% Copyright (c) SysBrain, S M Veres 19-05-2001 
 
 
 
%  Define default input values:
 
if nargin<7, aequal=0>1;end;
if nargin<6, resol=100;end; resi=1/resol;
if nargin<5, styl='-';end;
if nargin<4, col='blue';end;
if nargin<2, a=[1 2];end;
 
%  Perform diagnostics:
 
d1=size(E,2);d=d1-1;
if nargin<2 & d==3, a=[1 2 3];end;
 
%  Display projected ellipsoid onto an axes pair:
 
if length(a)==2,
   
   if nargin>2, 
      axes(axin); axout=axin;
   else 
      axout=newplot;
	end;
 
%  Computeg the projection onto an axes pair:
 
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(2),2)=1;
   EP=projell(E,SM); 
 
%  Compute graphical 2D output:
 
   Ec=ellicov(EP); ce=ellcent(EP); Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';
   lin=line(XY(:,1),XY(:,2));
   set(lin,'color',col);
   set(lin,'LineStyle',styl);
   
   if aequal, axis equal;end;
end;
 
%  Display projected ellipsoid onto 3 axes pairs:
 
 
if length(a)==3,
   
   if nargin>2, 
      axes(axin(1));
      axout1=axin(1);
   else 
      subplot(221),axout1=newplot;
	end;
 
%  Compute the projection onto an axes pair:
	
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(2),2)=1;
   EP=projell(E,SM);
 
%  Compute graphical 2D output:
   
   Ec=ellicov(EP); ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   lin=line(XY(:,1),XY(:,2));
   set(lin,'color',col);
   set(lin,'LineStyle',styl);
   if aequal, axis equal;end;
   
   if nargin>2, 
      axes(axin(2));
      axout2=axin(2);
  else 
      subplot(222),axout2=newplot;
	end;
 
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(3),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   lin=line(XY(:,1),XY(:,2));
   set(lin,'color',col);
   set(lin,'LineStyle',styl);
   if aequal, axis equal;end;
   
   if nargin>2, 
      axes(axin(3));
      axout3=axin(3);
   else 
      subplot(223),axout3=newplot;
	end;
 
   SM=zeros(d,2);SM(a(2),1)=1;SM(a(3),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   ellip=line(XY(:,1),XY(:,2));
   set(ellip,'color',col);
   set(ellip,'LineStyle',styl);
   if aequal, axis equal;end;
    
   axout=[axout1 axout2 axout3];
end;
 
%  Display projected ellipsoid onto 6 axes pairs:
 
if length(a)==4,
   
   if nargin>2, 
      axes(axin(1));
      axout1=axin(1);
   else 
      subplot(321),axout1=newplot;
	end;
   
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(2),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   lin=line(XY(:,1),XY(:,2));
   set(lin,'color',col);
   set(lin,'LineStyle',styl);
  if aequal, axis equal;end;  
   
   if nargin>6, 
      axes(axin(2));
      axout2=axin(2);
   else 
      subplot(322),axout2=newplot;
	end;
 
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(3),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   lin=line(XY(:,1),XY(:,2));
   set(lin,'color',col);
   set(lin,'LineStyle',styl);
   if aequal, axis equal;end;
 
   if nargin>2, 
      axes(axin(3));
      axout3=axin(3);
   else 
      subplot(323),axout3=newplot;
	end;
 
   SM=zeros(d,2);SM(a(1),1)=1;SM(a(4),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   ellip=line(XY(:,1),XY(:,2));
   set(ellip,'color',col);
   set(ellip,'LineStyle',styl);
   if aequal, axis equal;end;
   
   if nargin>2, 
      axes(axin(4));
      axout3=axin(4);
   else 
      subplot(324),axout4=newplot;
	end;
 
   SM=zeros(d,2);SM(a(2),1)=1;SM(a(3),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   ellip=line(XY(:,1),XY(:,2));
   set(ellip,'color',col);
   set(ellip,'LineStyle',styl);
   if aequal, axis equal;end;
   
   if nargin>2, 
      axes(axin(5));
      axout3=axin(5);
   else 
      subplot(325),axout5=newplot;
	end;
 
   SM=zeros(d,2);SM(a(2),1)=1;SM(a(4),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   ellip=line(XY(:,1),XY(:,2));
   set(ellip,'color',col);
   set(ellip,'LineStyle',styl);
   if aequal, axis equal;end;
   
   if nargin>2, 
      axes(axin(6));
      axout3=axin(6);
   else 
      subplot(326),axout6=newplot;
	end;
 
   SM=zeros(d,2);SM(a(3),1)=1;SM(a(4),2)=1;
   EP=projell(E,SM);
   Ec=ellicov(EP);
   ce=ellcent(EP);
   Ec2=sqrtm(Ec);
   dirs=[cos(pi*(0:resi:2)') sin(pi*(0:resi:2)')];
   XY=dirs*Ec2+ones(size(dirs,1),1)*ce';;
   ellip=line(XY(:,1),XY(:,2));
   set(ellip,'color',col);
   set(ellip,'LineStyle',styl);
   if aequal, axis equal;end;
 
   axout=[axout1 axout2 axout3 axout4 axout5 axout6];
end;
 
 
return;
